//******************************************************************************
//
// Unknown Enemy
// Sim Mission 2 - Epee Strike At Kilrathi Base
//
// Created by: Jakub Majewski  <qmajewski@yahoo.co.uk>
// Last modified: May 17, 2002
//
//******************************************************************************

mission s2;

// In this mission, the player leads a strike force of Epees
// in an attack on a Kilrathi starbase while a large
// Kilrathi force is refuelling there. The aim of this strike
// is to destroy the refuelling base, thus leaving the rest of
// the fleet stranded and vulnerable to further attacks.
// The fleet is extremely well defended. His only hope is a
// quick attack followed by an immediate withdrawal.

#AddToSearchPath("$uesrc$");

#include wcp;
#include consts;
#include UE;

#AddToSearchPath("$wcue$\language\");
#AddToSearchPath("$wcue$\language\pilots\");

#strings spacefli, targetid;

#SetOutputPath("$wcue$\mission\");
#sector: "b.sec";

var Alive = 0, BaseDead = false, m_Player_NAV2, x, y, z, m_Player_returns = false;
Const
  Nav_1 = 1,
  Nav_2 = 2;

object Light1(Light)
  x: 0;
  y: 0;
  z: 0;
  LightType: LIGHT_Ambient;
  LightColor: 0.3, 0.3, 0.3;
end;

object Nav1(Navpoint)
  x: 0;
  y: 0;
  z: 0;
  main: M_Nav1;
  name: spacefli["Nav 1"];
  navdata: 1, 5000;
end;

object Player(Player)
  obj: epee;
  x: 0;
  y: 0;
  z: 2500;
  main: M_Player;
  pilot: PILOT_Casey1;
end;



// The player's wing - 5 Epees

object Alpha2(Ship)
  obj: epee;
  x: -50;
  y: 0;
  z: 2500;
  main: M_Alpha;
  targstr: targetid["ALPHA 2"];
  pilot: PILOT_Gold;
end;

object Alpha3(Ship)
  obj: epee;
  x: 50;
  y: 0;
  z: 2500;
  main: M_Alpha;
  targstr: targetid["ALPHA 3"];
  pilot: PILOT_BloodHound;
end;

object Alpha4(Ship)
  obj: epee;
  x: 100;
  y: -5;
  z: 2495;
  main: M_Alpha;
  targstr: targetid["ALPHA 4"];
  pilot: PILOT_Huntress;
end;

object Alpha5(Ship)
  obj: epee;
  x: 150;
  y: -5;
  z: 2495;
  main: M_Alpha;
  targstr: targetid["ALPHA 5"];
  pilot: PILOT_Edge;
end;

object Nav2(Navpoint)
  x: 0;
  y: 0;
  z: 38000;
  main: M_Nav2;
  name: spacefli["Nav 2"];
  navdata: 2, 7500;
end;

object StarBase(Capship)
  obj: kstarbas;
  x: 45;
  y: -390;
  z: 42500;
  main: M_StarBase;
  death: D_StarBase;
  direction: 180, 0, 0;
  pilot: 82;
end;

function M_GetPos(ShipID);
begin
  x := SF_GetXObj(ShipID);
  y := SF_GetYObj(ShipID);
  z := SF_GetZObj(ShipID);
end;

function M_KilFighter;
begin
  SF_SetObjectFlag(OF_alignment, ALIGN_Evil_Kilrathi);
  SF_BindToActionSphere(2);
  SF_ActivateSelf(0);

  while(1) do begin
    AI_WaitSeconds(1);
    if (SF_GetDistance(StarBase) > 3000) then begin
      AI_AttackNothing(1);
      AI_GotoObjRange(StarBase, 1500);
      AI_AttackNothing(0);
    end;
  end;
end;

function M_KilDeath;
begin
  Alive := Alive - 1;
end;

function M_SpawnNearObject(shipId, count, obj);
var
  ox, oy, oz;

begin
  x := SF_GetXObj(obj);
  y := SF_GetYObj(obj);
  z := SF_GetZObj(obj);

  while(count > 0) do begin
    ox := x + SYS_Random(100) + 200;
    oy := y + SYS_Random(100) + 200;
    oz := z + SYS_Random(100) + 200;

    if (Alive < 20) then NAV_CreateShip(shipId, PILOT_Kat_Ace1, 0, @M_KilFighter, @M_KilDeath, ox, oy, oz);
    AI_WaitMilliseconds(275);
    Alive := Alive + 1;
    count := count - 1;

  end;
end;

function MAIN;
begin
  MS_RunSpaceflight(0);
  Alive := 0;
end;

function M_Player;
begin
  SF_SetObjectFlag(OF_Alignment, ALIGN_CONFED);
  SF_BindToActionSphere(0);
  SF_ActivateSelf(0);
  SF_PlayerSwitchToCam(CamID_cockpit, Player);

  while (1) do begin
    AI_WaitSeconds(1);
  end;
end;

// *************************** Home Base (Nav 1) **********
// ********************************************************
object Intrepid(Capship)
  obj: UE_SHIP_Intrepid;
  x: 0;
  y: 0;
  z: 3500;
  main: M_Dauntl;
  direction: 0,0,0;
  pilot: Pilot_Dauntless;
end;

function M_Nav1;
var setup = true;
begin
  while (1) do begin
    if (NAV_WithinSphere(Player)) then begin
      NAV_ActivateSelf;

      if (setup) then begin
        SF_ActivateObject(Intrepid, AO_appear);
        setup := false;
      end;
      if (m_Player_returns) then begin
        SF_AutopilotDisable;
        AI_WaitSeconds(10);
        SF_Exit;
      end;

      NAV_SetPlayerNav(Nav_2);

      while (NAV_WithinSphere(Player)) do AI_WaitSeconds(1);
      NAV_DeactivateSelf;
      m_Player_NAV2 := true;
    end;
    AI_WaitSeconds(1);
  end;
end;

function M_Dauntl;
begin
  AI_WaitUntilActive;
  SF_SetObjectFlag(OF_alignment, ALIGN_Confed);
  SF_BindToActionSphere(1);
  AI_MuteComms;

  while(1) do
    AI_WaitSeconds(1);
end;

// **************************** Kilrathi Force (Nav 2) ****
// ********************************************************

object Hakhhi(Capship)
  obj: fralthi;
  x: 340;
  y: -390;
  z: 42500;
  main: M_CapCentre;
  direction: 0, 0, 0;
  pilot: 82;
end;

object Zuthrak(Capship)
  obj: ralari;
  x: -250;
  y: -390;
  z: 42200;
  main: M_CapBack;
  direction: 0, 0, 0;
  pilot: 82;
end;

object Utarakh(Capship)
  obj: ralari;
  x: -200;
  y: -390;
  z: 42800;
  main: M_CapFront;
  direction: 0, 0, 0;
  pilot: 82;
end;

function M_Nav2;
var setup = true;
begin
  while (1) do begin
    if (NAV_WithinSphere(Player)) then begin
      NAV_SetPlayerNav(Nav_1);
      NAV_ActivateSelf;

      if (setup) then begin
        SF_AutopilotDisable;
        SF_ActivateObject(StarBase, AO_appear);
        SF_ActivateObject(Hakhhi, AO_appear);
        SF_ActivateObject(Zuthrak, AO_appear);
        SF_ActivateObject(Utarakh, AO_appear);
        M_SpawnNearObject(UE_SHIPID_Salthi, 2, StarBase);
        AI_WaitSeconds(10);
        M_SpawnNearObject(UE_SHIPID_Salthi, 2, StarBase);
        AI_WaitSeconds(5);
        M_SpawnNearObject(UE_SHIPID_Dralthi, 3, StarBase);
        setup := false;
        m_Player_returns := true;
      end;

      AI_WaitSeconds(5);

      while (NAV_WithinSphere(Player)) do begin
        AI_WaitMilliSeconds(5);
        SF_AutopilotDisable;
        if (BaseDead < 1) then begin
          M_SpawnNearObject(UE_SHIPID_Vaktoth_Fighter, 2, StarBase);
          AI_WaitSeconds(15);
        end;
        if (BaseDead < 1) then begin
          M_SpawnNearObject(UE_SHIPID_Dralthi, 2, StarBase);
          AI_WaitSeconds(15);
        end;
        if (BaseDead < 1) then begin
          M_SpawnNearObject(UE_SHIPID_Dralthi, 2, StarBase);
          AI_WaitSeconds(15);
        end;
        SF_AutopilotResumeNormal;
      end;
      NAV_DeactivateSelf;
    end;
    AI_WaitSeconds(1);
  end;
end;

function M_Alpha;
begin
  SF_SetObjectFlag(OF_alignment, ALIGN_Confed);
  SF_BindToActionSphere(0);
  SF_ActivateSelf(0);
  AI_AddToWing(Player);

  while(1) do
    AI_WaitSeconds(5);
end;

function M_StarBase;
begin
  AI_WaitUntilActive;
  SF_SetObjectFlag(OF_alignment, ALIGN_Evil_Kilrathi);
  SF_BindToActionSphere(2);

  while(1) do
    AI_WaitSeconds(1);
end;

function M_CapCentre;
begin
  AI_WaitUntilActive;
  SF_SetObjectFlag(OF_Alignment, ALIGN_Neutral);
  SF_BindToActionSphere(2);
  AI_SetThrottle(0);
  AI_WaitSeconds(30);
  SF_SetObjectFlag(OF_Alignment, ALIGN_Evil_Kilrathi);

  while(1) do
    AI_WaitSeconds(1);
end;

function M_CapBack;
begin
  AI_WaitUntilActive;
  SF_SetObjectFlag(OF_Alignment, ALIGN_Neutral);
  SF_BindToActionSphere(2);
  AI_SetThrottle(0);
  AI_WaitSeconds(30);
  SF_SetObjectFlag(OF_Alignment, ALIGN_Evil_Kilrathi);

  while(1) do
    AI_WaitSeconds(1);
end;

function M_CapFront;
begin
  AI_WaitUntilActive;
  SF_SetObjectFlag(OF_Alignment, ALIGN_Neutral);
  SF_BindToActionSphere(2);
  AI_SetThrottle(0);
  AI_WaitSeconds(20);
  SF_SetObjectFlag(OF_Alignment, ALIGN_Evil_Kilrathi);

  while(1) do
    AI_WaitSeconds(1);
end;

function D_StarBase;
begin
  BaseDead := true;
  SF_SetMissionSuccess;
end;
