//******************************************************************************
//
// Unknown Enemy
// Mission 0 - Prelude
//
// Created by:
//               Jakub Majewski  <qmajewski@yahoo.co.uk>
//               Thomas Bruckner <thomas.bruckner@aon.at>
//
// Last modified: Apr 9th, 2004
//
//******************************************************************************

mission ue0;

#AddToSearchPath("$uesrc$");

#SetRooms ("cic.rom", "rec.rom");

// **************  Block Files  **************

#SetOutputPath("$wcue$\mission\");
#file "block190.pas";
#file "block191.pas";
#file "block198.pas";

// **************  Comm Files  **************

#SetOutputPath("$wcue$\language\pilots\");
#file "strings\pilots\srs20.pas";

#SetOutputPath("$wcue$\comms\");
#file "comms\srs20.pas";

// 0 = "Civilian freighter, we've detected contraband in your hold. You are ordered
//      to follow us to Beaufort Station immediately." (Player)

// 1 = "Who's gonna make us?" (Smuggler)

// 2 = "Hold your fire! We surrender!" (Smuggler)

// 3 = "Setting nav course for Beaufort Station." (Ghost)

// 4 = "A smuggler? Good work, Lt. Colonel. Our Scims will make sure it docks.
//      You can return to your patrol." (Beaufort)

// 5 = "The Captain sends his congratulations, sir. You're cleared to land." (Dauntless)


// **************  Main Program  **************

#sector: "t.sec";
#name: 1;

#AddToSearchPath("$wcue$\language\");
#include wcp;
#include consts;
#include uepilots;
#include UE;
#include comms;

#strings objectiv;
#strings spacefli;
#strings targetid;

#SetKillboard(PILOT_Faris, PILOT_Defender, PILOT_Ocelot, PILOT_Hellcat,
              PILOT_Night, PILOT_Doc, PILOT_Shark, PILOT_Thor,
              PILOT_Killer, PILOT_Bloodhound, PILOT_Edge, PILOT_Mage,
              PILOT_Phantom, PILOT_Gold, PILOT_Blade, PILOT_Huntress,
              PILOT_Ghost, PILOT_Gryphon, PILOT_Warrior);

#SetOutputPath("$wcue$\mission\");

var
  m_Failed = true,
  m_Event,
  m_AliveEnemies,
  m_DeadEnemies,
  m_Player_Returns,
  m_Comm = -1,
  Navs_Scanned,
  x,
  y,
  z,
  DeadSmuggler = 0;

external
  g_Secret_EasterEgg_Active;

const
  NAV_Dauntless = 1,
  NAV_1 = 2,
  NAV_2 = 3,
  NAV_3 = 4,
  NAV_Beaufort = 5,

  EVENT_Smuggler_Hostile = 1,
  EVENT_Smuggler_Friendly = 2,
  EVENT_Smuggler_At_Beaufort = 3,
  EVENT_Takeoff_Start = 4,
  EVENT_Takeoff_Complete = 5,
  EVENT_Land_Player = 6,
  EVENT_Activate_Landing_Cam = 7,
  EVENT_Dauntless_Ready = 8,
  EVENT_Final_Approach = 9;

objective mobj_patrol
  hidden: false;
  type: MOBJ_Primary;
  text: objectiv["Patrol All NAV Points"];
  status: MOBJ_Incomplete;
  counter: false;
end;

objective mobj_scan_freighters
  hidden: false;
  type: MOBJ_Bonus;
  text: objectiv["Scan Freighters"];
  status: MOBJ_Incomplete;
  counter: true;
end;

objective mobj_escort_smuggler
  hidden: true;
  type: MOBJ_Bonus;
  text: objectiv["Escort Freighter to Beaufort"];
  status: MOBJ_Incomplete;
  counter: false;
end;

object Dauntless(Capship) as "BWS Dauntless"
  obj: UE_SHIP_Dauntless;
  x: -10000;
  y: 0;
  z: 4100;
  main: M_Dauntless;
  brief: B_Dauntless;
  color: 0, 0.35, 0.35, 1;
  direction: 0, 0, 0;
  pilot: PILOT_Dauntless;
end;

object Player(Player)
  obj: UE_SHIP_Scimitar;
  x: -10000;
  y: 5;
  z: 2100;
  main: M_Player;
  brief: B_Player;
  color: 0, 0.8, 0.8, 0.0;
  pilot: PILOT_Casey1;
end;

function MAIN;
begin
  MS_ChangePilotSquadron(PILOT_Drago, 1);
  MS_ChangePilotSquadron(PILOT_Steel, 1);
  MS_ChangePilotSquadron(PILOT_November, 1);
  MS_ChangePilotSquadron(PILOT_Echo, 1);
  MS_ChangePilotSquadron(PILOT_Professor, 1);
  MS_ChangePilotSquadron(PILOT_Ogre, 1);
  MS_ChangePilotSquadron(PILOT_Ninja, 1);
  MS_RunGameflow(0);
  MS_RunBriefing;
  MS_ShipSelector(UE_SELECTOR_Scimitar, UE_SELECTOR_Epee);
  MS_RunSpaceflight(0);
  MS_RunDebriefing;
end;

function S_Drone;
begin
  SF_SetObjectFlag(OF_vulnerable, 1);
  SF_SetObjectFlag(OF_alignment, ALIGN_Neutral);
  SF_BindToActionSphere(NAV_2);
  SF_ActivateSelf(AO_appear);
  m_AliveEnemies := m_AliveEnemies + 1;

  AI_AttackNothing(1);
  AI_SetThrottle(0);

  until(m_Event = EVENT_Smuggler_Hostile) do
    AI_WaitMilliSeconds(1);

  //Player has identified smuggler, turn hostile
  SF_SetObjectFlag(OF_alignment, ALIGN_Evil_Kilrathi);

  AI_AttackNothing(0);
  AI_AttackEnemies;

  while (1) do
    AI_WaitSeconds(1);
end;

function S_DroneDeath;
begin
  m_DeadEnemies := m_DeadEnemies + 1;
end;

function M_SpawnNearObjectDrone(shipid, count, obj);
//
// this function spawns "count" ships of type "shipID"
// at coordinates near the object given in "obj"
//
var
  ox, oy, oz;
begin
  x := SF_GetXObj(obj);
  y := SF_GetYObj(obj);
  z := SF_GetZObj(obj);

  while(count > 0) do begin
    ox := x + SYS_Random(2000) + 1000;
    oy := y + SYS_Random(200) + 100;
    oz := z + SYS_Random(2000) + 1000;

    NAV_CreateShip(shipId, PILOT_Confed, 0, @S_Drone, @S_DroneDeath, ox, oy, oz);
    count := count - 1;
  end;
end;

function M_CountEnemies;
begin
  Result := m_AliveEnemies - m_DeadEnemies;
end;

function M_GetPos(ShipID);
begin
  x := SF_GetXObj(ShipID);
  y := SF_GetYObj(ShipID);
  z := SF_GetZObj(ShipID);
end;

function F_InitLanding; forward;
function F_PlayerTakeoff; forward;
function F_PlayerLanding; forward;
function F_DauntlessLanding; forward;
// ************************* Dauntless NAV *************************

object NavD(Navpoint)
  x: -10000;
  y: 0;
  z: 2000;
  main: M_NavD;
  brief: B_NavD;
  color: 0, 1, 1, 1;
  name: spacefli["Dauntless Nav"];
  navdata: 1, 30000;
end;

object Ghost(Ship)
  obj: UE_SHIP_Scimitar;
  x: -9500;
  y: 100;
  z: 4100;
  main: M_Ghost;
  brief: B_Ghost;
  color: 0, 0, 0, 1;
  targstr: 1;
  pilot: PILOT_Ghost;
end;

function M_NavD;
var
  setup = true;
begin
  NAV_SetEjectSequence(ES_SAR_pickup);

  while(1) do begin
    if (NAV_WithinSphere(Player)) then begin
      NAV_ActivateSelf;

      if (m_Player_Returns) then begin
        if (Navs_Scanned = 3) then begin
          SF_ObjectiveSetComplete(mobj_patrol);
          SF_SetMissionSuccess;
          AI_WaitSeconds(3);
          // Dauntless: The Captain sends his congratulations, sir. You're cleared to land.
          //SF_PrintText(209);
          m_Comm := 5;
        end else begin
          SF_SetMissionFailure;
          SF_ObjectiveSetFailure(mobj_patrol);
          AI_WaitSeconds(3);
          m_Comm := 6;
        end;

        // now landing
        F_InitLanding;
      end;

      if (setup) then begin
        SF_ActivateObject(Dauntless, 0);
        setup := false;
      end;

      NAV_SetPlayerNav(NAV_1);

      while(NAV_WithinSphere(Player)) do begin
        AI_WaitSeconds(1);
      end;
      NAV_DeactivateSelf;
      m_Player_Returns := true;
    end;
    AI_WaitSeconds(1);
  end;
end;

function M_Player;
begin
  SF_SetObjectFlag(OF_Alignment, ALIGN_CONFED);
  SF_BindToActionSphere(0);
  SF_SetBaseShip(Dauntless);
  F_PlayerTakeoff;

  while (1) do begin
    if (m_Event = EVENT_Land_Player) then
      F_PlayerLanding;
    AI_WaitSeconds(1);
  end;
end;

function M_Ghost;
begin
  SF_SetObjectFlag(OF_alignment, ALIGN_Confed);
  SF_SetObjectFlag(OF_vulnerable, false);
  SF_BindToActionSphere(0);
  SF_ActivateSelf(0);
  until (M_Event = EVENT_Takeoff_Complete) do
    AI_WaitMilliSeconds(1);
  AI_AddToWing(Player);

  while(1) do begin
    if (m_Comm = 0) then begin
      AI_SendSpecialComm(20, 0);
      m_Comm := -1;
    end;
    if (m_Comm = 3) then begin
      AI_SendSpecialComm(20, 3);
      m_Comm := -1;
    end;
    if (m_Event = EVENT_Land_Player) then begin
      AI_RemoveFromWing;
      AI_IgnoreCollisions(1);
      AI_AttackNothing(1);
      AI_SetThrottle(0);
    end;
    AI_WaitMilliseconds(100);
  end;
end;

function M_Dauntless;
begin
  AI_WaitUntilActive;
  SF_SaveObjectState(true);

  SF_SetObjectFlag(OF_alignment, ALIGN_Confed);
  SF_BindToActionSphere(NAV_Dauntless);

  while(1) do begin
    if (m_Comm = 5) then begin
      AI_SendSpecialComm(29, 3);
      m_Comm := -1;
    end;
    if (m_Comm = 6) then begin
      AI_SendSpecialComm(22, 8);
      m_Comm := -1;
    end;
    if (m_Event = EVENT_Activate_Landing_Cam) then
      F_DauntlessLanding;
    AI_WaitMilliseconds(1);
  end;
end;

// ***************************** NAV 1 *****************************

object Nav1(Navpoint)
  x: 46400;
  y: 45000;
  z: 23000;
  main: M_Nav1;
  brief: B_Nav1;
  color: 0, 1, 1, 1;
  name: spacefli["Nav 1"];
  navdata: 2, 30000;
end;

function M_FriendlyFreighter;
begin
  SF_ObjectiveIncrementTotal(mobj_scan_freighters);
  SF_ObjectiveIncrementTotalNeededForSuccess(mobj_scan_freighters);
  AI_WaitUntilActive;

  SF_SetObjectFlag(OF_alignment, ALIGN_Neutral);
  SF_BindToActionSphere(0);

  AI_SetThrottle(90);

  while(1) do begin
    AI_WaitSeconds(1);
    if (SF_GetDistance(Player) < 300) then begin
      // COMPUTER: freighter scanned...
      SF_PrintText(190);
      SF_ObjectiveIncrementCount(mobj_scan_freighters);
      SF_SetObjectFlag(OF_alignment, ALIGN_Confed);
      while(1) do
        AI_WaitSeconds(1);
    end;
  end;
end;

object Bannister(CapShip)
  obj: UE_SHIP_Freighter;
  x: 46000;
  y: 45650;
  z: 26000;
  main: M_FriendlyFreighter;
  pilot: PILOT_TCS_Barkley;
end;

object Pertuxan(CapShip)
  obj: UE_SHIP_Freighter;
  x: 46600;
  y: 45020;
  z: 25500;
  main: M_FriendlyFreighter;
  pilot: PILOT_TCS_Barkley;
end;

function M_Nav1;
var
  setup = true;
begin
  while(1) do begin
    NAV_SetEjectSequence(ES_SAR_pickup);
    if (NAV_WithinSphere(Player)) then begin
      NAV_ActivateSelf;

      if (setup) then begin
        Navs_Scanned := Navs_Scanned + 1;

        //2 Freighters (Pilot_TCS_Barkley)
        SF_ActivateObject(Bannister, 0);
        SF_ActivateObject(Pertuxan, 0);

        setup := false;
      end;

      NAV_SetPlayerNav(NAV_2);

      while(NAV_WithinSphere(Player)) do begin
        AI_WaitSeconds(1);
      end;
      SF_DeactivateObject(Bannister, 0);
      SF_DeactivateObject(Pertuxan, 0);
      NAV_DeactivateSelf;
    end;
    AI_WaitSeconds(1);
  end;
end;

// ***************************** NAV 2 *****************************

object Nav2(Navpoint)
  x: 110232;
  y: 31200;
  z: 3000;
  main: M_Nav2;
  brief: B_Nav2;
  color: 0, 1, 1, 1;
  name: spacefli["Nav 2"];
  navdata: 3, 30000;
end;

object Tavistock(CapShip)
  obj: UE_SHIP_Freighter;
  x: 110780;
  y: 31000;
  z: 5990;
  main: M_Smuggler;
  death: D_Smuggler;
  pilot: PILOT_TCS_Barkley;
end;

object Asteroids(ABStart)
  x: 110232;
  y: 31200;
  z: 3000;
  absdata: 1, 2000, 4000;
end;

object Asteroids2(Debrsfld)
  x: 112000;
  y: 31500;
  z: 6000;
  absdata: 1,         // belt id
           200,      // number of objects
           320;      // diameter
  actionsphere: NAV_2;
end;

object Unknown(Cargo)
  x: 112000;
  y: 31500;
  z: 6000;
  actionsphere: NAV_2;
  main: M_EasterEgg;
  death: D_EasterEgg;
end;

function M_EasterEgg;
begin
  SF_ActivateSelf(0);
  SF_SetContents(159);
  while(1) do AI_WaitSeconds(1);
end;

function D_EasterEgg;
begin
  g_Secret_EasterEgg_Active := true;
  SYS_PlaySFX(13);
end;

function M_Smuggler;
begin
  SF_ObjectiveIncrementTotal(mobj_scan_freighters);
  SF_ObjectiveIncrementTotalNeededForSuccess(mobj_scan_freighters);
  AI_WaitUntilActive;
  SF_SetChildObjectVulnerable(Tavistock, PART_ChildBridge, false);
  SF_SetChildObjectVulnerable(Tavistock, PART_ChildEngine, false);

  SF_SetObjectFlag(OF_alignment, ALIGN_Neutral);
  SF_BindToActionSphere(NAV_2);

  AI_SetThrottle(0);

  while(1) do begin
    AI_WaitSeconds(1);
    if (SF_GetDistance(Player) < 300) then begin
      SF_ObjectiveIncrementCount(mobj_scan_freighters);

      SF_AutopilotDisable;

      // "[Computer] Scan complete. Warning - contraband detected...
      SF_PrintText(191);
      AI_WaitSeconds(8);

      // "[Ghost] Civilian Freighter, we've detected contraband...
      //SF_PrintText(192);
      m_Comm := 0;
      AI_WaitSeconds(8);

      // "[Freighter] Who's gonna make us?"
      //SF_PrintText(193);
      AI_SendSpecialComm(20, 1);

      AI_WaitSeconds(2);
      m_Event := EVENT_Smuggler_Hostile;
      SF_SetChildObjectVulnerable(Tavistock, PART_ChildBridge, true);
      SF_SetChildObjectVulnerable(Tavistock, PART_ChildEngine, true);
      AI_WaitSeconds(1);
      SF_SetObjectFlag(OF_alignment, ALIGN_Evil_Kilrathi);
      // "[Freighter] Kill them, boys!"
      AI_SendSpecialComm(20, 5);

      while(m_Event = EVENT_Smuggler_Hostile) do
        AI_WaitSeconds(3);

      // "[Freighter] Hold your fire! We surrender!"
      // SF_PrintText(194);
      AI_SendSpecialComm(20, 2);
      AI_MuteComms;
      SF_BindToActionSphere(0);
      AI_SetAutopilotData(-80, -20, 100);

      AI_WaitSeconds(2);
      SF_SetObjectFlag(OF_alignment, ALIGN_Confed);

      until(m_Event = EVENT_Smuggler_At_Beaufort) do
        AI_WaitSeconds(1);

      SF_BindToActionSphere(NAV_Beaufort);
      AI_SetAutopilotData(0, 0, -10000);

      AI_SetThrottle(50);

      while(1) do
        AI_WaitSeconds(1);
    end;
  end;
end;

function D_Smuggler;
begin
  DeadSmuggler := true;
end;

function M_Nav2;
var
  setup = true;
begin
  while(1) do begin
    NAV_SetEjectSequence(ES_SAR_pickup);
    if (NAV_WithinSphere(Player)) then begin
      NAV_ActivateSelf;

      if (setup) then begin
        Navs_Scanned := Navs_Scanned + 1;
        SF_ActivateObject(Tavistock, 0);
        SF_ActivateObject(Unknown, 0);
        M_SpawnNearObjectDrone(UE_SHIPID_ConfedDrone, 8, Tavistock);
        setup := false;
      end;

      NAV_SetPlayerNav(NAV_3);

      while(NAV_WithinSphere(Player)) do begin
        if (m_Event = EVENT_Smuggler_Hostile) then begin
          while(M_CountEnemies > 0) do
            AI_WaitSeconds(1);

          while(SF_GetNumComponentPartsObj(Tavistock, PART_ChildGunTurret) > 0) do
            AI_WaitSeconds(1);

          AI_WaitSeconds(2);
          if (DeadSmuggler = false) then begin
            SF_ObjectiveEnable(mobj_escort_smuggler);
            m_Event := EVENT_Smuggler_Friendly;

            AI_WaitSeconds(9);

            // "[Ghost] Setting nav course for Beaufort Station."
            // SF_PrintText(195);
            m_Comm := 3;
            AI_WaitSeconds(1);

            NAV_ShowNav(NAV_Beaufort);
            NAV_SetPlayerNav(NAV_Beaufort);
          end;
          SF_AutopilotResumeNormal;
        end;

        AI_WaitSeconds(1);
      end;
      NAV_DeactivateSelf;
    end;
    AI_WaitSeconds(1);
  end;
end;

// ***************************** NAV 3 *****************************

function M_EscapingFreighter; forward;

object Nav3(Navpoint)
  x: 70000;
  y: 21000;
  z: -33200;
  main: M_Nav3;
  brief: B_Nav3;
  color: 0, 1, 1, 1;
  name: spacefli["Nav 3"];
  navdata: 4, 30000;
end;

object Eleanor(CapShip)
  obj: UE_SHIP_Freighter;
  x: 70000;
  y: 21000;
  z: -30800;
  main: M_EscapingFreighter;
  pilot: PILOT_TCS_Barkley;
  direction: 20, 0, 0;
end;

object JumpPoint(JumpPoint)
  x: 69200;
  y: 21000;
  z: -29800;
  actionsphere: NAV_3;
end;

function M_Nav3;
var
  setup = true;
begin
  while(1) do begin
    NAV_SetEjectSequence(ES_SAR_pickup);
    if (NAV_WithinSphere(Player)) then begin
      NAV_ActivateSelf;

      if (setup) then begin
        Navs_Scanned := Navs_Scanned + 1;
        SF_ActivateObject(Eleanor, 0);
        SF_ActivateObject(JumpPoint, 0);
        setup := false;
      end;

      NAV_SetPlayerNav(NAV_Dauntless);

      while(NAV_WithinSphere(Player)) do begin
        AI_WaitSeconds(1);
      end;
      NAV_DeactivateSelf;
    end;
    AI_WaitSeconds(1);
  end;
end;

function M_EscapingFreighter;
begin
  SF_ObjectiveIncrementTotal(mobj_scan_freighters);
  SF_ObjectiveIncrementTotalNeededForSuccess(mobj_scan_freighters);
  AI_FaceObject(JumpPoint);
  AI_WaitUntilActive;

  SF_SetObjectFlag(OF_alignment, ALIGN_Neutral);
  SF_BindToActionSphere(NAV_3);

  AI_SetThrottle(100);

  SYS_TimerSet(30);

  while(1) do begin
    AI_WaitSeconds(1);
    if (SF_GetDistance(Player) < 300) then begin
      SF_PrintText(190);
      SF_ObjectiveIncrementCount(mobj_scan_freighters);
      SF_SetObjectFlag(OF_alignment, ALIGN_Confed);
      AI_WaitSeconds(12);
      SF_DeactivateSelf(1);
      while(1) do
        AI_WaitSeconds(1);
    end;

    if (SYS_TimerGet = 0) then begin
      SF_DeactivateSelf(1);
      while(true) do
        AI_WaitSeconds(10);
    end;
  end;
end;

// **************************** Beaufort *****************************

object NavB(Navpoint)
  x: 92700;
  y: 110000;
  z: -93200;
  main: M_NavB;
  brief: B_NavB;
  color: 0, 1, 1, 1;
  name: spacefli["Beaufort NAV"];
  navdata: 5, 30000;
end;

object Beaufort(CapShip) as "Beaufort Station"
  obj: UE_SHIP_Beaufort;
  x: 92890;
  y: 110200;
  z: -91500;
  main: M_Beaufort;
  pilot: PILOT_Beaufort;
  direction: 0, 10, 15;
  actionsphere: NAV_Beaufort;
end;

function M_ScimPatrol1;
begin
  SF_ActivateSelf(0);
  SF_SetObjectFlag(OF_vulnerable, 0);
  SF_SetObjectFlag(OF_alignment, ALIGN_CONFED);
  SF_BindToActionSphere(NAV_Beaufort);
  AI_MuteComms;
  AI_ClearDefendList;
  AI_AttackNothing(1);
  while (1) do
    AI_GotoObjRelFrame(Tavistock, -100, -100, 0);
end;

function M_ScimPatrol2;
begin
  SF_ActivateSelf(0);
  SF_SetObjectFlag(OF_vulnerable, 0);
  SF_SetObjectFlag(OF_alignment, ALIGN_CONFED);
  SF_BindToActionSphere(NAV_Beaufort);
  AI_MuteComms;
  AI_ClearDefendList;
  AI_AttackNothing(1);
  while (1) do
    AI_GotoObjRelFrame(Tavistock, 100, -100, 0);
end;

function M_ScimPatrol3;
begin
  SF_ActivateSelf(0);
  SF_SetObjectFlag(OF_vulnerable, 0);
  SF_SetObjectFlag(OF_alignment, ALIGN_CONFED);
  SF_BindToActionSphere(NAV_Beaufort);
  AI_MuteComms;
  AI_ClearDefendList;
  AI_AttackNothing(1);
  while (1) do
    AI_GotoObjRelFrame(Tavistock, 100, 100, 0);
end;

function M_ScimPatrol4;
begin
  SF_ActivateSelf(0);
  SF_SetObjectFlag(OF_vulnerable, 0);
  SF_SetObjectFlag(OF_alignment, ALIGN_CONFED);
  SF_BindToActionSphere(NAV_Beaufort);
  AI_MuteComms;
  AI_ClearDefendList;
  AI_AttackNothing(1);
  while (1) do
    AI_GotoObjRelFrame(Tavistock, -100, 100, 0);
end;

function NULL;
begin
  Result := 0;
end;

function M_NavB;
var
  setup = true,
  posz = -91500;
begin
  NAV_ActivateSelf;
  SF_ActivateObject(Beaufort, 0);
  NAV_DeactivateSelf;

  NAV_HideSelf;
  while(1) do begin
    NAV_SetEjectSequence(ES_SAR_pickup);
    if (NAV_WithinSphere(Player)) then begin
      NAV_ActivateSelf;

      if (setup) then begin
        m_Event := EVENT_Smuggler_At_Beaufort;
        SF_ObjectiveSetComplete(mobj_escort_smuggler);

        // note how i'm using a local variable posz, since the 8th parameter
        // must be simple expression without operators.
        NAV_CreateShip(UE_SHIPID_Ferret, PILOT_Confed, targetid["Cap 1"], @M_ScimPatrol1, @NULL, 92000, 110200, posz);
        NAV_CreateShip(UE_SHIPID_Ferret, PILOT_Confed, targetid["Cap 2"], @M_ScimPatrol2, @NULL, 95000, 111200, posz);
        NAV_CreateShip(UE_SHIPID_Ferret, PILOT_Confed, targetid["Cap 3"], @M_ScimPatrol3, @NULL, 95000, 110200, posz);
        NAV_CreateShip(UE_SHIPID_Ferret, PILOT_Confed, targetid["Cap 4"], @M_ScimPatrol4, @NULL, 92000, 111200, posz);

        AI_WaitSeconds(3);

        // "[Beaufort Station] A smuggler? Good work, Lt. Colonel.
        //  Our Ferrets will make sure it docks. You can return to your patrol."
        //SF_PrintText(196);
        m_Comm := 4;

        setup := false;
      end;

      NAV_SetPlayerNav(NAV_3);

      while(NAV_WithinSphere(Player)) do begin
        AI_WaitSeconds(1);
      end;
      NAV_DeactivateSelf;
    end;
    AI_WaitSeconds(1);
  end;
end;

function M_Beaufort;
begin
  AI_WaitUntilActive;

  SF_SetObjectFlag(OF_alignment, ALIGN_Confed);
  SF_BindToActionSphere(NAV_Beaufort);
  //AI_MuteComms;

  while(1) do begin
    if (m_Comm = 4) then begin
      AI_SendSpecialComm(20, 4);
      m_Comm := -1;
    end;
    AI_WaitMilliseconds(250);
  end;
end;

// ******************** Begin Briefing ********************

function B_Player;
begin
  BRIEF_CAM_SetActive(1);
  BRIEF_CAM_SetPos(0, 600, 0);
  BRIEF_CAM_TrackObj(Player);

  BRIEF_SetAppearance(UE_APPEARANCE_Scimitar);
  BRIEF_FaceObject(Nav1);
  BRIEF_Activate;

  BRIEF_WaitSeconds(1);

  // "You will fly the morning patrol together with Ghost."
  BRIEF_VoiceOver(20, 0, 4);
  BRIEF_WaitSeconds(3);

  BRIEF_MoveObjSeconds(Nav1, 4);
  SYS_PlaySFX(SFX_BRIEF_Activate);

  // "Patrol all three NAV points. You are unlikely to encounter
  // any trouble."
  BRIEF_VoiceOver(20, 1, 5);

//  BRIEF_WaitSeconds(1);
  BRIEF_MoveObjSeconds(Nav2, 5);
  SYS_PlaySFX(SFX_BRIEF_Activate);

  // "However, it may be worthwhile to inspect the cargo on
  // encountered freighters."
  BRIEF_VoiceOver(20, 2, 5);

//  BRIEF_WaitSeconds(1);
  BRIEF_MoveObjSeconds(Nav3, 4);
  SYS_PlaySFX(SFX_BRIEF_Activate);

//  BRIEF_WaitSeconds(1);
  BRIEF_MoveObjSeconds(NavD, 7);

  BRIEF_Exit;

  while (1) do
    BRIEF_WaitSeconds(1);
end;

function B_Ghost;
begin
  BRIEF_SetAppearance(UE_APPEARANCE_Scimitar);
  BRIEF_AttachToObj(Player, 0, 25, -5);

  BRIEF_Activate;

  while(1) do
    BRIEF_WaitSeconds(10);
end;

function B_Dauntless;
begin
  BRIEF_SetAppearance(UE_APPEARANCE_Dauntless);
  BRIEF_FaceObject(Nav1);
  BRIEF_Activate;

  while(1) do
    BRIEF_WaitSeconds(10);
end;

function B_NavD;
begin
  BRIEF_Activate;
  BRIEF_DisplayName(1);
  BRIEF_SetSize(160);
  BRIEF_SetAppearance(1);

  while (1) do
    BRIEF_WaitSeconds(1);
end;

function B_Nav1;
begin
  BRIEF_Activate;
  BRIEF_DisplayName(1);
  BRIEF_SetSize(150);
  BRIEF_SetAppearance(1);

  while (1) do
    BRIEF_WaitSeconds(1);
end;

function B_Nav2;
begin
  BRIEF_Activate;
  BRIEF_DisplayName(1);
  BRIEF_SetSize(100);
  BRIEF_SetAppearance(1);

  while (1) do
    BRIEF_WaitSeconds(1);
end;

function B_Nav3;
begin
  BRIEF_Activate;
  BRIEF_DisplayName(1);
  BRIEF_SetSize(120);
  BRIEF_SetAppearance(1);

  while (1) do
    BRIEF_WaitSeconds(1);
end;

function B_NavB;
begin
  BRIEF_Activate;
  BRIEF_DisplayName(1);
  BRIEF_SetSize(125);
  BRIEF_SetAppearance(1);

  while (1) do
    BRIEF_WaitSeconds(1);
end;

// **************** Takeoff/Landing routines **************
// ********************************************************
// Camera stuff

object Camera(Camera)
  x: 0;
  y: 0;
  z: 0;
  main: M_Camera;
end;

function F_Takeoff(select); forward;
function F_Landing(select); forward;

function M_Camera;
begin
  while(1) do
  begin
    if (m_Event = EVENT_Takeoff_Start) then
      F_Takeoff(SYS_Random(3));
    if (m_Event = EVENT_Activate_Landing_Cam) then
      F_Landing(SYS_Random(3));
    AI_WaitMilliSeconds(15);
  end;
end;

function F_Takeoff(select);
begin
  SF_CAM_TrackObj(Player);

  if (select = 0) then
    SF_CAM_SetFollowObj(Player, -30, 35, -40);
  if (select = 1) then
    SF_CAM_SetFollowObj(Player, -10, 35, 80);
  if (select = 2) then
    SF_CAM_SetFollowObj(Player, 0, 5, 40);

  SF_ActivateSelf(0);
  until (m_Event = EVENT_Takeoff_Complete) do
    AI_WaitSeconds(1);
  SF_CAM_TrackNothing;
  SF_DeactivateSelf(0);
end;

function F_Landing(select);
begin
  SF_CAM_HideDust;
  SF_CAM_TrackObj(NavD);
  SF_CAM_SetFollowObj(NavD, 0, 1, 0);
  SF_ActivateSelf(0);
  until (m_Event = EVENT_Dauntless_Ready) do
    AI_WaitMilliSeconds(1);
  SF_CAM_TrackObj(Dauntless);

  if (select = 0) then
    SF_CAM_SetFollowObj(Dauntless, -200, 200, -350);
  if (select = 1) then
    SF_CAM_SetFollowObj(Dauntless, -50, 200, 500);
  if (select = 2) then
    SF_CAM_SetFollowObj(Dauntless, 400, 100, 300);

  until (m_Event = EVENT_Final_Approach) do
    AI_WaitMilliSeconds(5);
  SF_CAM_TrackObj(Player);

  select := SYS_Random(3);
  if (select = 0) then
    SF_CAM_SetFollowObj(Player, -3, 2, 15);
  if (select = 1) then
    SF_CAM_SetFollowObj(Player, 3, 4, -15);
  if (select = 2) then
    SF_CAM_SetFollowObj(Player, -9, 2, 5);

  AI_WaitSeconds(30);
end;

// Player stuff

function F_InitLanding;
begin
  SF_AutopilotDisable;
  m_Event := EVENT_Land_Player;
  until (M_Event = EVENT_Activate_Landing_Cam) do AI_WaitSeconds(1);
  AI_WaitSeconds(30);
  SF_Exit;
end;

function F_PlayerTakeoff;
begin
  M_GetPos(Dauntless);
  SF_SetWorldPosition(x+15, y-25, z);
  SF_SetObjectFlag(OF_Collidable, false);
  AI_PLR_ControlAssume;
  AI_SetThrottle(0);
  AI_WaitSeconds(1);
  SF_ActivateSelf(0);
  AI_WaitSeconds(1);
  AI_SetThrottle(100);
  AI_WaitMilliSeconds(1500);
  M_Event := EVENT_Takeoff_Start;
  while (SF_GetDistance(Dauntless) < 500) do
    HCL_AI_GotoObjRelWorld_nonblock(Dauntless, 15, -20, 700);
  M_Event := EVENT_Takeoff_Complete;
  SF_SetObjectFlag(OF_Collidable, true);
  AI_PLR_ControlResume;
  SF_PlayerSwitchToCam(CamID_cockpit, Player);
end;

function F_PlayerLanding;
begin
  while (SF_GetDistance(Dauntless) > 300) do AI_WaitMilliSeconds(1);
  AI_PLR_ControlAssume;
  SF_SetObjectFlag(OF_Collidable, false);
  M_Event := EVENT_Activate_Landing_Cam;
  HCL_EmptyFuel;
  AI_SetThrottle(0);
  until (SF_GetVelocityObject(Player) < 5) do
    AI_WaitMilliSeconds(1);
  AI_SetThrottle(0);

  until (m_Event = EVENT_Dauntless_Ready) do
    AI_WaitMilliSeconds(500);

  // Teleport to position relative to Dauntless
  M_GetPos(Dauntless);
  SF_SetWorldPosition(x, y, z-350);
  AI_FaceObject(Dauntless);
  SF_SetWorldPosition(x, y-25, z-350);
  AI_SetThrottle(50);
  until (SF_GetDistance(Dauntless) < 50) do AI_WaitMilliSeconds(5);
  M_Event := EVENT_Final_Approach;
  SYS_PlaySFX(SFX_Engines_Power_Down);
  AI_WaitSeconds(3);
  AI_SetThrottle(0);
  AI_WaitSeconds(5);
  SF_Exit;
end;

// Dauntless stuff

function F_DauntlessLanding;
begin
  if (SF_GetVelocityObject(Dauntless) > 0) then
  begin
    AI_SetThrottle(0);
    AI_WaitSeconds(5);
  end;

  // Teleport to position relative to NavD, face NavD
  M_GetPos(NavD);
  SF_SetWorldPosition(x, y, z+1000);
  AI_FaceObject(NavD);
  m_Event := EVENT_Dauntless_Ready;
  AI_WaitSeconds(25);
  SF_Exit;
end;
