//******************************************************************************
//
// Unknown Enemy
// Mission 2a - Threat Removal
//
// Created by: Thomas Bruckner <thomas.bruckner@aon.at>
// Modified by: Jakub Majewski <qmajewski@yahoo.co.uk>
// Last modified: Apr 9th, 2004
//
//******************************************************************************

mission ue2a;

#sector: "t.sec";
#SetRooms ("cic.rom", "rec.rom");

#SetOutputPath("$wcue$\mission\");

#AddToSearchPath("$uesrc$");
#AddToSearchPath("$wcue$\language\");
#include wcp, consts, uepilots;
#include UE;
#include Comms;

#strings objectiv;
#strings spacefli;
#strings targetid;

#SetOutputPath("$wcue$\mission\");

#SetKillboard(PILOT_Faris, PILOT_Defender, PILOT_Ocelot, PILOT_Hellcat,
              PILOT_Night, PILOT_Doc, PILOT_Shark, PILOT_Thor,
              PILOT_Killer, PILOT_Bloodhound, PILOT_Edge, PILOT_Mage,
              PILOT_Phantom, PILOT_Gold, PILOT_Blade, PILOT_Huntress,
              PILOT_Ghost, PILOT_Gryphon, PILOT_Warrior);

var
  m_Event,
  m_PlayerReturns,
  m_PlayerReturned,
  m_AliveEnemies,
  m_DeadEnemies,
  m_Ralari_Dead,
  m_Kamikaze_Count,
  m_Comm = -1,
  m_Takeoff_Fralthi = 0,
  xpos, ypos, zpos;

external
  g_Fralthi_Dead,
  g_UE_2a_Won;

const
  EVENT_Land_Player = 1,
  EVENT_Takeoff_Start = 2,
  EVENT_Takeoff_Complete = 3,
  EVENT_Activate_Landing_Cam = 4,
  EVENT_Dauntless_Ready = 5,
  EVENT_Final_Approach = 6,
  EVENT_Dauntless_Hit_Bad = 7,
  EVENT_Dauntless_Dead = 10,
  NAV_D = 1,
  NAV_1 = 2;

#name: 3;

objective mobj_protect_dauntless
  hidden: true;
  type: MOBJ_Primary;
  text: objectiv["Protect Dauntless"];
  status: MOBJ_Incomplete;
  counter: false;
end;

objective mobj_protect_fralthi
  hidden: true;
  type: MOBJ_Primary;
  text: objectiv["Protect Fralthi"];
  status: MOBJ_Incomplete;
  counter: false;
end;

objective mobj_destroy_ralari
  hidden: false;
  type: MOBJ_Primary;
  text: objectiv["Destroy Ralari"];
  status: MOBJ_Incomplete;
  counter: false;
end;

function S_EnemyFighter; forward;
function S_EnemyFighterDeath; forward;

function M_Spawn(shipId, count, x, y, z);
//
// this function spawns "count" ships of type "shipID"
// at coordinates around x, y, z
//
var
  ox, oy, oz;
begin
  while(count > 0) do begin
    ox := x + SYS_Random(1600) - 800;
    oy := y + SYS_Random(1600) - 800;
    oz := z + SYS_Random(1600) - 800;

    NAV_CreateShip(shipId, 84, 0, @S_EnemyFighter, @S_EnemyFighterDeath, ox, oy, oz);
    AI_WaitMilliseconds(275);
    count := count - 1;
  end;
end;

function M_SpawnNearObject(shipId, count, obj);
//
// this function spawns "count" ships of type "shipID"
// at coordinates near the object given in "obj"
//
var
  x, y, z,
  ox, oy, oz;
begin
  x := SF_GetXObj(obj);
  y := SF_GetYObj(obj);
  z := SF_GetZObj(obj);

  while(count > 0) do begin
    ox := x + SYS_Random(300) + 200;
    oy := y + SYS_Random(300) + 200;
    oz := z + SYS_Random(100) + 150;

    NAV_CreateShip(shipId, 84, 0, @S_EnemyFighter, @S_EnemyFighterDeath, ox, oy, oz);
    AI_WaitMilliseconds(275);
    count := count - 1;
  end;
end;

function M_WaitUntilDead;
//
// this function waits until all enemies spawned by M_Spawn*
// have been killed.
//
begin
  until(m_DeadEnemies = m_AliveEnemies) do
    AI_WaitSeconds(4);
end;

function M_WaitUntilDeadTimeOut(sec);
begin
  AI_WaitSeconds(1);
  SYS_TimerSet(sec - 1);
  until ((SYS_TimerGet = 0) or (m_DeadEnemies = m_AliveEnemies)) do begin
    AI_WaitSeconds(1);
  end;
end;

function M_GetPos(ShipID);
begin
  xpos := SF_GetXObj(ShipID);
  ypos := SF_GetYObj(ShipID);
  zpos := SF_GetZObj(ShipID);
end;

function F_InitLanding; forward;
function F_PlayerTakeoff; forward;
function F_PlayerTakeoffFralthi; forward;
function F_PlayerLanding; forward;
function F_DauntlessLanding; forward;

// ************************* Dauntless NAV *************************

object NavD(Navpoint)
  x: 0;
  y: 0;
  z: 0;
  main: M_NavD;
  brief: B_NavD;
  name: spacefli["Dauntless Nav"];
  color: 0, 1.0, 1.0, 1.0;
  navdata: 1, 45000;
end;

object Night(Ship)
  obj: UE_SHIP_Gratha_Bomber_BW;
  x: 0;
  y: 500;
  z: 800;
  main: M_Night;
  brief: B_Night;
  targstr: 1;
  color: 0, 0.2, 0.2, 1.0;
  pilot: PILOT_Night;
end;

object Player(Player)
  obj: UE_SHIP_Gratha_Bomber_BW;
  x: 300;
  y: 200;
  z: -500;
  main: M_Player;
  brief: B_Player;
  color: 0, 1.0, 1.0, 0.0;
  direction: 180, 0, 0;
  pilot: PILOT_Casey1;
end;

object Dauntless(Capship) as "BWS Dauntless"
  obj: UE_SHIP_Dauntless;
  x: 0;
  y: 0;
  z: -500;
  main: M_Dauntless;
  death: D_Dauntless;
  brief: B_Dauntless;
  color: 0, 0.5, 0.5, 1.0;
  direction: 0, 0, 0;
  pilot: PILOT_Dauntless;
end;

object Fralthi(Capship) as "Fralthi"
  obj: UE_SHIP_Fralthi;
  x: 1400;
  y: 330;
  z: -350;
  main: M_Fralthi;
  death: D_Fralthi;
  direction: 0, 0, 0;
  pilot: PILOT_Fralthi;
end;

object Ralari(Capship) as "Ralari"
  obj: UE_SHIP_Ralari;
  x: 220;
  y: -50;
  z: 4210;
  main: M_Ralari;
  death: D_Ralari;
  brief: B_Ralari;
  color: 0, 1.0, 0.5, 0.5;
  direction: 0, 0, 0;
  pilot: PILOT_Kat_Capship;
end;

//object Stunt_Gratha(Ship)
//  obj: UE_SHIP_Gratha_Bomber;
//  x: 0;
//  y: 0;
//  z: 0;
//  main: M_Stunt_Gratha;
//  pilot: 84;
//end;

object Belt1(ABStart)
  x: 0;
  y: 0;
  z: 4000;
  absdata: 1, 350, 1000;  //id, objects, diameter
end;

object AControl1(ABCPoint)
  x: 500;
  y: 500;
  z: 3000;
  ABCDATA: 1, 1;
end;

object AControl2(ABCPoint)
  x: -500;
  y: -500;
  z: 2800;
  ABCDATA: 1, 2;
end;

object AControl3(ABCPoint)
  x: 200;
  y: 400;
  z: 2200;
  ABCDATA: 1, 3;
end;

object AControl4(ABCPoint)
  x: -200;
  y: -400;
  z: 1800;
  ABCDATA: 1, 4;
end;

function MAIN;
begin
  MS_RunGameflow(0);
  MS_RunBriefing;
  SYS_PlayMovie(9010);
  MS_RunSpaceflight(0);
  MS_RunDebriefing;
end;

function S_EnemyFighter;
var
  target,
  a;
begin
  SF_SetObjectFlag(OF_vulnerable, 1);
  SF_SetObjectFlag(OF_alignment, ALIGN_Evil_Kilrathi);
  SF_BindToActionSphere(0);
  SF_ActivateSelf(AO_appear);
  m_AliveEnemies := m_AliveEnemies + 1;

  if (m_PlayerReturned) then begin
    // assign some targets...
    a := SYS_Random(5);
    if ((a = 1) or (a = 2)) then AI_AddToAttackList(Fralthi, 300);
    if (a = 3) then AI_AddToAttackList(Dauntless, 300);
  end;

  while (1) do begin
    if (m_Ralari_Dead) then begin
      AI_WaitSeconds(SYS_Random(5));

      // let's kamikaze
      if (SF_GetActiveStatus(Fralthi) = AS_Active) then
        target := Fralthi
      else if (SF_GetActiveStatus(Dauntless) = AS_Active) then
        target := Dauntless
      else
        target := Player;

      AI_IgnoreCollisions(1);
      AI_AttackNothing(1);

      AI_ReplenishMissilesAndFuel;

      AI_SetThrottle(100);
      AI_GotoObjRange(target, 1200);
      AI_FaceObject(target);
      AI_FireMissile(7);

      AI_ReplenishMissilesAndFuel;
//      SF_SetObjectFlag(OF_collidable, false);

      AI_SetThrottle(100);
      AI_GotoObjRange(target, 800);
      AI_FaceObject(target);
      AI_FireMissile(7);

      AI_GotoObjRange(target, 90);
      m_Kamikaze_Count := m_Kamikaze_Count + 1;
      SF_DestroySelf;

      while(1) do
        AI_WaitSeconds(5);
    end;
    AI_WaitSeconds(1);
  end;
end;

function S_EnemyFighterDeath;
begin
  m_DeadEnemies := m_DeadEnemies + 1;
end;

// ********** BEGIN Spwaning Routines for CatPatrol **********
function S_CatPatrol;
var
  rad;
begin
  SF_SetObjectFlag(OF_alignment, ALIGN_Confed);
//  SF_SetObjectFlag(OF_vulnerable, False);
  SF_ActivateSelf(0);

  AI_WaitSeconds(1);
  SF_BindToActionSphere(1);
  AI_AttackNothing(1);

  rad := SYS_Random(400)+100;

  while(m_PlayerReturns = 0) do begin
    AI_GotoObjRelWorld(Fralthi, 0, rad, rad);
    AI_GotoObjRelWorld(Fralthi, rad, rad, 0);
    AI_GotoObjRelWorld(Dauntless, 0, rad , -rad);
    AI_GotoObjRelWorld(Dauntless, -rad, rad , 0);
  end;

  AI_AttackNothing(0);
  AI_AddToDefendList(Fralthi, 100);
  AI_AddToIgnoreList(Ralari, 1);

  AI_WaitSeconds(SYS_Random(8));
  AI_SendComm(COMM_Pilot_Report_Attacking);
  //AI_MuteComms;

  AI_AttackEnemies;

  while (1) do begin
    if (m_Event = EVENT_Dauntless_Hit_Bad) then begin
      AI_WaitSeconds(SYS_Random(4));
      SF_DestroySelf;
    end;
    AI_WaitSeconds(1);
    AI_GotoObjRelWorld(Fralthi, 0, rad, rad);
    AI_GotoObjRelWorld(Fralthi, rad, rad, 0);
    AI_GotoObjRelWorld(Dauntless, 0, rad , -rad);
    AI_GotoObjRelWorld(Dauntless, -rad, rad , 0);
  end;
end;

function NULL;
begin
end;

function M_SpawnNearObjectCatPatrol(shipId, count, obj);
var
  x, y, z,
  ox, oy, oz;
begin
  x := SF_GetXObj(obj);
  y := SF_GetYObj(obj);
  z := SF_GetZObj(obj);

  while(count > 0) do begin
    ox := x + SYS_Random(100) + 100;
    oy := y + SYS_Random(100) + 100;
    oz := z + SYS_Random(100) + 100;

    NAV_CreateShip(shipId, 85, 0, @S_CatPatrol, @NULL, ox, oy, oz);
    AI_WaitMilliseconds(275);
    count := count - 1;
  end;
end;
// *********** END Spwaning Routines for CatPatrol ***********

function S_ConfedBackup;
var
  rad;
begin
  SF_SetObjectFlag(OF_alignment, ALIGN_Confed);
  SF_SetObjectFlag(OF_vulnerable, false);
  SF_ActivateSelf(0);
  SF_BindToActionSphere(1);
  AI_AddToAttackList(Ralari, 100);
  AI_AttackEnemies;

  while (1) do begin
    if (m_Event = EVENT_Dauntless_Hit_Bad) then begin
      AI_WaitSeconds(SYS_Random(4));
      SF_DestroySelf;
    end;
    AI_GotoObjRelWorld(Dauntless, 0, rad, rad);
    AI_GotoObjRelWorld(Dauntless, rad, rad, 0);
    AI_GotoObjRelWorld(Fralthi, 0, rad , -rad);
    AI_GotoObjRelWorld(Fralthi, -rad, rad , 0);
    AI_WaitSeconds(1);
    AI_ReplenishMissilesAndFuel;
  end;
end;

function S_ConfedPatrol;
var
  rad;
begin
  SF_SetObjectFlag(OF_alignment, ALIGN_Confed);
  SF_ActivateSelf(0);

  AI_WaitSeconds(1);
  SF_BindToActionSphere(1);
  AI_AttackNothing(1);

  rad := SYS_Random(300)+150;

  while(m_PlayerReturns = 0) do begin
    AI_GotoObjRelWorld(Dauntless, 0, rad, rad);
    AI_GotoObjRelWorld(Dauntless, rad, rad, 0);
    AI_GotoObjRelWorld(Fralthi, 0, rad , -rad);
    AI_GotoObjRelWorld(Fralthi, -rad, rad , 0);
  end;

  AI_AddToDefendList(Dauntless, 100);
  AI_AttackNothing(0);
  AI_AddToAttackList(Ralari, 100);
  AI_AttackEnemies;

  while (1) do begin
    if (m_Event = EVENT_Dauntless_Hit_Bad) then begin
      AI_WaitSeconds(SYS_Random(4));
      SF_DestroySelf;
    end;
    AI_GotoObjRelWorld(Dauntless, 0, rad, rad);
    AI_GotoObjRelWorld(Dauntless, rad, rad, 0);
    AI_GotoObjRelWorld(Fralthi, 0, rad , -rad);
    AI_GotoObjRelWorld(Fralthi, -rad, rad , 0);
    AI_WaitSeconds(1);
  end;
end;

function M_NavD;
var
  setup = true;
begin
  NAV_SetEjectSequence(ES_alien_pickup_MIA);
  while(1) do begin
    if (NAV_WithinSphere(Player)) then begin
      NAV_ActivateSelf;

      if (setup) then begin
        M_SpawnNearObjectCatPatrol(UE_SHIPID_Dralthi, 2, Fralthi);
        NAV_CreateShip(UE_SHIPID_Scimitar, PILOT_Warrior, 1, @S_ConfedPatrol, @NULL, -500, 500, 0);
        NAV_CreateShip(UE_SHIPID_Scimitar, PILOT_Edge, 1, @S_ConfedPatrol, @NULL, -400, 500, 0);

        NAV_SetPlayerNav(NAV_1);
        setup := false;
      end;

      if (m_PlayerReturns) then begin
        // The Player returns to answer the distress call...
        m_PlayerReturned := True;
        SF_ActivateObject(Ralari, 0);
        M_SpawnNearObject(UE_SHIPID_Salthi, 8, Ralari);
        NAV_CreateShip(UE_SHIPID_Vaktoth_Fighter, PILOT_Vaqi, 0, @S_CatPatrol, @NULL, 500, 300, 300);

        M_WaitUntilDeadTimeOut(40);
        NAV_CreateShip(UE_SHIPID_Gratha_Bomber_BW, PILOT_Faris, 1, @S_ConfedPatrol, @NULL, -1800, 500, 0);
        NAV_CreateShip(UE_SHIPID_Gratha_Bomber_BW, PILOT_Defender, 1, @S_ConfedPatrol, @NULL, -1800, 550, 0);

        if (SF_GetActiveStatus(Ralari) = AS_Active) then begin
          M_SpawnNearObject(UE_SHIPID_Salthi, 3, Ralari);
          M_SpawnNearObject(UE_SHIPID_Gratha_Fighter, 1, Ralari);
          M_SpawnNearObject(UE_SHIPID_Gratha_Bomber, 2, Ralari);
          AI_WaitSeconds(35);
          M_SpawnNearObject(UE_SHIPID_Salthi, 3, Ralari);
          M_SpawnNearObject(UE_SHIPID_Gratha_Fighter, 1, Ralari);
          M_SpawnNearObject(UE_SHIPID_Gratha_Bomber, 4, Ralari);
          AI_WaitSeconds(45);
          NAV_CreateShip(UE_SHIPID_Gratha_Bomber_BW, PILOT_Doc, 1, @S_ConfedPatrol, @NULL, -1800, 500, 0);
          NAV_CreateShip(UE_SHIPID_Gratha_Bomber_BW, PILOT_Ocelot, 1, @S_ConfedBackup, @NULL, -1800, 550, 0);
        end else begin
          M_Spawn(UE_SHIPID_Salthi, 4, 0, 0, 4210);
          M_Spawn(UE_SHIPID_Gratha_Fighter, 3, 0, 0, 4210);
          M_Spawn(UE_SHIPID_Gratha_Bomber, 3, 0, 0, 4210);
        end;


        M_WaitUntilDead;

        NAV_SetEjectSequence(ES_SAR_pickup);
        SF_ObjectiveSetComplete(mobj_protect_dauntless);

        g_UE_2a_Won := (g_Fralthi_dead = 0);

        if (g_UE_2a_Won) then begin
          SF_ObjectiveSetComplete(mobj_protect_fralthi);
          SF_SetMissionSuccess;
          m_Comm := 6;
        end
        else m_Comm :=7;

        AI_WaitSeconds(9);

        F_InitLanding;
//        m_Event := EVENT_Land_Player;

        while(1) do
          AI_WaitSeconds(5);
      end;

      while(NAV_WithinSphere(Player)) do begin
        AI_WaitSeconds(1);
      end;
      NAV_DeactivateSelf;
    end;
    AI_WaitSeconds(1);
  end;
end;

function M_Player;
begin
  SF_SetObjectFlag(OF_Alignment, ALIGN_CONFED);
  SF_BindToActionSphere(0);
  SF_SetBaseShip(Dauntless);
  SF_ActivateSelf(0);
  //F_PlayerTakeoff;
  F_PlayerTakeoffFralthi;

  while (1) do begin
    if ((m_PlayerReturns) and (m_PlayerReturned = false)) then begin
      AI_WaitSeconds(20);

      AI_SendSpecialCommFrom(22, 3, PILOT_Dauntless);
      AI_SendSpecialCommFrom(22, 4, PILOT_Dauntless);

      SF_ObjectiveEnable(mobj_protect_fralthi);
      SF_ObjectiveEnable(mobj_protect_dauntless);

      AI_WaitSeconds(77);

      if (m_PlayerReturned = false) then begin
        m_Event := EVENT_Dauntless_Hit_Bad;
        AI_SendSpecialCommFrom(22, 5, PILOT_Dauntless);
        SF_AutoPilotDisable;
        AI_WaitSeconds(9);
        SF_ExitEndGame(2);
      end;
    end;

    if (m_Event = EVENT_Land_Player) then
      F_PlayerLanding;

    if (m_Event = EVENT_Dauntless_Dead) then begin
      AI_WaitSeconds(10);
      SF_ExitEndGame(2);
    end;

    AI_WaitSeconds(1);
  end;
end;

function M_Night;
begin
  SF_SetObjectFlag(OF_alignment, ALIGN_Confed);
  SF_SetObjectFlag(OF_vulnerable, False);
  SF_BindToActionSphere(0);
  SF_ActivateSelf(0);
  until (M_Event = EVENT_Takeoff_Complete) do
    AI_WaitMilliSeconds(1);
  AI_AddToWing(Player);

  while(1) do begin
    AI_WaitMilliSeconds(100);
    if (m_PlayerReturned) then
      SF_SetObjectFlag(OF_vulnerable, true);
    if (m_Event = EVENT_Land_Player) then begin
      AI_RemoveFromWing;
      AI_IgnoreCollisions(1);
      AI_AttackNothing(1);
      AI_SetThrottle(0);
    end;
  end;
end;

function M_Dauntless;
begin
  SF_SaveObjectState(true);
  SF_SetObjectFlag(OF_alignment, ALIGN_Confed);
  SF_ActivateSelf(0);
  AI_WaitSeconds(1);

  SF_BindToActionSphere(1);

  until (M_Event = EVENT_Takeoff_Complete) do begin
    AI_WaitSeconds(1);
    AI_SetThrottle(0);
  end;
  AI_SetThrottle(25);

  SF_SetPilotImmortal(PILOT_Gryphon, 1);
  SF_SetPilotImmortal(PILOT_Gold, 1);
  SF_SetPilotImmortal(PILOT_Mage, 1);
  SF_SetPilotImmortal(PILOT_Night, 1);
  SF_SetPilotImmortal(PILOT_Phantom, 1);
  SF_SetPilotImmortal(PILOT_Defender, 1);
  SF_SetPilotImmortal(PILOT_Faris, 1);
  SF_SetPilotImmortal(PILOT_Huntress, 1);
  SF_SetPilotImmortal(PILOT_Hellcat, 1);
  SF_SetPilotImmortal(PILOT_Warrior, 1);
  SF_SetPilotImmortal(PILOT_Ocelot, 1);
  SF_SetPilotImmortal(PILOT_Doc, 1);
  SF_SetPilotImmortal(PILOT_Edge, 1);
  SF_SetPilotImmortal(PILOT_Vaqi, 1);

  while(1) do begin
    AI_WaitMilliSeconds(1);

    if (SF_GetActiveStatus(Ralari) = AS_Active) then begin
      if (SF_GetDistance(Ralari) < 700) then begin
        //AI_FaceObject(Ralari);
        //AI_SetThrottle(100);
        AI_SetThrottle(0);
      end;
    end;

    if (m_Comm = 6) then begin
        AI_SendSpecialCommFrom(22, 6, PILOT_Dauntless);
        m_Comm := 8;
      end;
    if (m_Comm = 7) then begin
        AI_SendSpecialCommFrom(22, 7, PILOT_Dauntless);
        m_Comm := 8;
      end;

    if (m_Comm = 8) then begin
      AI_SendSpecialCommFrom(22, 8, PILOT_Dauntless);
      m_Comm := -1;
    end;

    if (m_Event = EVENT_Activate_Landing_Cam) then
      F_DauntlessLanding;

    if (m_Event = EVENT_Dauntless_Hit_Bad) then begin
      SF_AutoPilotDisable;
      SF_DestroySelf;
    end;
  end;
end;

function D_Dauntless;
begin
  SF_ObjectiveSetFailure(mobj_protect_dauntless);
  //m_Event := EVENT_Dauntless_Dead;
end;

function M_Fralthi;
begin
  SF_SaveObjectState(true);
  SF_SetObjectFlag(OF_alignment, ALIGN_Confed);
  SF_ActivateSelf(0);

  AI_WaitSeconds(1);
  SF_BindToActionSphere(1);
  until (M_Event = EVENT_Takeoff_Complete) do begin
    AI_WaitSeconds(1);
    AI_SetThrottle(0);
  end;
  //AI_SetThrottle(25);

  while(1) do begin
    AI_WaitMilliseconds(500);
    if (m_Kamikaze_Count = 5) then
      SF_DestroySelf;
    AI_SetThrottle(0);

    if (m_Event = EVENT_Dauntless_Hit_Bad) then
      SF_DestroySelf;
  end;
end;

function D_Fralthi;
begin
  g_Fralthi_Dead := true;
  SF_ObjectiveSetFailure(mobj_protect_fralthi);
  SF_SetMissionFailure;
end;

function M_Ralari;
begin
  AI_WaitUntilActive;
  m_AliveEnemies := m_AliveEnemies + 1;

  SF_SetObjectFlag(OF_alignment, ALIGN_Evil_Kilrathi);
//  SF_SetObjectFlag(OF_vulnerable, false);
  SF_BindToActionSphere(0);

  //AI_AddToAttackList(Fralthi, 500);
  //AI_AddToIgnoreList(Player, 1);
  //AI_AddToIgnoreList(Night, 1);

  while(1) do begin
    if (SF_GetActiveStatus(Fralthi) = AS_Active) then begin
      AI_FaceObject(Fralthi);
      AI_SetThrottle(100);
      AI_GotoObjRelFrame(Fralthi, 600, 0, 600);
      while (1) do
        AI_WaitSeconds(5);
    end;

    AI_WaitSeconds(10);
  end;
end;

function D_Ralari;
begin
  m_DeadEnemies := m_DeadEnemies + 1;
  m_Ralari_Dead := 1;
  SF_ObjectiveSetComplete(mobj_destroy_ralari);
end;

// **************************** Nav1 **************************

object Nav1(Navpoint)
  x: 55000;
  y: -2000;
  z: 5000;
  main: M_Nav1;
  brief: B_Nav1;
  name: spacefli["Nav 1"];
  color: 0, 1.0, 1.0, 1.0;
  navdata: 2, 15000;
end;

function M_Nav1;
var
  setup = true;
begin
  NAV_SetEjectSequence(ES_alien_pickup_MIA);
  while(1) do begin
    if (NAV_WithinSphere(Player)) then begin
      NAV_ActivateSelf;

      if (setup) then begin
        // 4 Dralthi (Kilrathi Aces),
        // 2 Gratha Bombers (Kilrathi Aces)

        M_Spawn(UE_SHIPID_Dralthi, 3, 55000, -2000, 7000);
        M_Spawn(UE_SHIPID_Gratha_Bomber, 2, 55200, -1500, 7600);

        m_PlayerReturns := true;

        M_WaitUntilDead;

        NAV_SetPlayerNav(NAV_D);
        NAV_DeactivateSelf;
        while(1) do
          AI_WaitSeconds(10);
      end;
    end;
    AI_WaitSeconds(1);
  end;
end;

// **************************** Nav2 **************************

object Nav2(Navpoint)
  x: 125002;
  y: -20000;
  z: 1000;
  main: M_Nav2;
  brief: B_Nav2;
  name: spacefli["Nav 2"];
  color: 0, 1.0, 1.0, 1.0;
  navdata: 3, 15000;
end;

function M_Nav2;
var
  setup = true;
begin
  NAV_SetEjectSequence(ES_alien_pickup_MIA);
  while(1) do begin
    if (NAV_WithinSphere(Player)) then begin
      NAV_ActivateSelf;

      if (setup) then begin
        SF_AutoPilotDisable;
        m_PlayerReturns := true;
        AI_WaitSeconds(22);
        m_Event := EVENT_Dauntless_Hit_Bad;
        NAV_SetPlayerNav(NAV_D);
        AI_WaitSeconds(5);
        SF_AutoPilotEnable;
        NAV_DeactivateSelf;
        while(1) do
          AI_WaitSeconds(10);
      end;
    end;
    AI_WaitSeconds(1);
  end;
end;

// **************************** Nav3 **************************

object Nav3(Navpoint)
  x: 122002;
  y: -10000;
  z: 41000;
  main: M_Nav1;
  brief: B_Nav3;
  name: spacefli["Nav 3"];
  color: 0, 1.0, 1.0, 1.0;
  navdata: 4, 15000;
end;

object Hyperion(Jumppoint)
  x: 122002;
  y: -8000;
  z: 41500;
  actionsphere: 4;
  color: 0, 1.0, 1.0, 1.0;
end;

object DummyNav(Navpoint)
  x: 122002;
  y: -8000;
  z: 41500;
  color: 0, 1.0, 1.0, 1.0;
  name: spacefli["Hyperion jump-point"];
  navdata: 4, 40000;
  main: M_DummyNav;
  brief: B_Jump;
end;

function M_DummyNav;
begin
  NAV_HideSelf;
  while(1) do
    AI_WaitSeconds(10);
end;

// ************************* Briefing *************************

var
  m_Ralari_blowup;

function B_NavD;
begin
  BRIEF_SetAppearance(1);
  BRIEF_DisplayName(1);
  BRIEF_SetSize(120);
  BRIEF_Activate;
  while(1) do
    BRIEF_WaitSeconds(10);
end;

function B_Nav1;
begin
  BRIEF_SetAppearance(1);
  BRIEF_DisplayName(1);
  BRIEF_SetSize(60);
  BRIEF_Activate;
  while(1) do
    BRIEF_WaitSeconds(10);
end;

function B_Nav2;
begin
  BRIEF_SetAppearance(1);
  BRIEF_DisplayName(1);
  BRIEF_SetSize(110);
  BRIEF_Activate;
  while(1) do
    BRIEF_WaitSeconds(10);
end;

function B_Nav3;
begin
  BRIEF_SetAppearance(1);
  BRIEF_DisplayName(0);
  BRIEF_SetSize(100);
  BRIEF_Activate;
  while(1) do
    BRIEF_WaitSeconds(10);
end;

function B_Jump;
begin
  BRIEF_SetAppearance(UE_APPEARANCE_JumpBuoy);
  BRIEF_DisplayName(1);
  BRIEF_Activate;
  while(1) do
    BRIEF_WaitSeconds(10);
end;

function B_Night;
begin
  BRIEF_SetAppearance(UE_APPEARANCE_Gratha);
  BRIEF_AttachToObj(Player, -20, 10, 0);
  BRIEF_Activate;
  while(1) do
    BRIEF_WaitSeconds(10);
end;

function B_Player;
begin
  BRIEF_CAM_SetPos(0, 800, -50);
  BRIEF_CAM_SetActive(1);
  BRIEF_CAM_TrackObj(Player);
  BRIEF_Activate;

  BRIEF_SetAppearance(UE_APPEARANCE_Gratha);
  BRIEF_Activate;
  BRIEF_WaitSeconds(1);

  // The Kilrathi commander of the Fralthi confirms that there is another
  // Kilrathi capital ship in this system. The ship is a Ralari-class
  // destroyer, and constitutes a severe threat for the Dauntless."]);

  BRIEF_Voiceover(22, 0, 11);
  BRIEF_WaitSeconds(12);

  BRIEF_VoiceOver(22, 1, 11);
  BRIEF_MoveObjSeconds(Nav1, 5);
  SYS_PlaySFX(SFX_BRIEF_Activate);

  // Alpha wing will inspect NAV 1, then proceed to NAV 2, where the Ralari
  // is believed to be. When the Ralari is located, bomb it with dumbfires
  // and retreat.

  BRIEF_MoveObjSeconds(Nav2, 5);
  BRIEF_WaitMilliseconds(100);
  m_Ralari_blowup := 1;

  BRIEF_WaitSeconds(1);

  // It is highly probable that the Ralari will attempt to retreat towards
  // the Hyperion jump point. If the destroyer is not found at NAV 2,
  // intercept it at NAV 3 and destroy it using torpedoes.

  BRIEF_VoiceOver(22, 2, 12);
  BRIEF_WaitSeconds(2);
  BRIEF_MoveObjSeconds(Nav3, 5);
  SYS_PlaySFX(SFX_BRIEF_Activate);

  BRIEF_MoveObjSeconds(NavD, 7);

  BRIEF_WaitSeconds(2);
  BRIEF_Exit;
end;

function B_Dauntless;
begin
  BRIEF_SetAppearance(UE_APPEARANCE_Dauntless);
  BRIEF_Activate;
  while (1) do
    BRIEF_WaitSeconds(10);
end;

function B_Ralari;
begin
  BRIEF_SetAppearance(UE_APPEARANCE_Ralari);
  BRIEF_Activate;
  BRIEF_AttachToObj(Nav2, 10, 0, 0);
  while(1) do begin
    BRIEF_WaitMilliseconds(150);
    if (m_Ralari_blowup) then begin
      SYS_PlaySFX(SFX_BRIEF_Blowup);
      BRIEF_WaitMilliseconds(50);
      BRIEF_Deactivate;
      while(1) do BRIEF_WaitSeconds(99);
    end;
  end;
end;


// **************** Takeoff/Landing routines **************
// ********************************************************
// Camera stuff

object Camera(Camera)
  x: 0;
  y: 0;
  z: 0;
  main: M_Camera;
end;

function F_Takeoff(select); forward;
function F_Landing(select); forward;

function M_Camera;
begin
  while(1) do
  begin
    if (m_Event = EVENT_Takeoff_Start) then
      F_Takeoff(SYS_Random(3));
    if (m_Event = EVENT_Activate_Landing_Cam) then
      F_Landing(SYS_Random(3));
    AI_WaitMilliSeconds(15);
  end;
end;

function F_Takeoff(select);
begin
  SF_CAM_TrackObj(Player);

  if (m_Takeoff_Fralthi) then begin
    if (select = 0) then
      SF_CAM_SetFollowObj(Player, -25, -10, 40);
    if (select = 1) then
      SF_CAM_SetFollowObj(Player, -45, -5, 15);
    if (select = 2) then
      SF_CAM_SetFollowObj(Player, -10, 65, 25);
  end
  else begin
    if (select = 0) then
      SF_CAM_SetFollowObj(Player, -30, 35, -40);
    if (select = 1) then
      SF_CAM_SetFollowObj(Player, -10, 35, 80);
    if (select = 2) then
      SF_CAM_SetFollowObj(Player, 0, 5, 40);
  end;

  SF_ActivateSelf(0);
  until (m_Event = EVENT_Takeoff_Complete) do
    AI_WaitSeconds(1);
  SF_CAM_TrackNothing;
  SF_DeactivateSelf(0);
end;

function F_Landing(select);
begin
  SF_CAM_HideDust;
  SF_CAM_TrackObj(NavD);
  SF_CAM_SetFollowObj(NavD, 0, 1, 0);
  SF_ActivateSelf(0);
  until (m_Event = EVENT_Dauntless_Ready) do
    AI_WaitMilliSeconds(1);
  SF_CAM_TrackObj(Dauntless);

  if (select = 0) then
    SF_CAM_SetFollowObj(Dauntless, -200, 200, -350);
  if (select = 1) then
    SF_CAM_SetFollowObj(Dauntless, -50, 200, 500);
  if (select = 2) then
    SF_CAM_SetFollowObj(Dauntless, 400, 100, 300);

  until (m_Event = EVENT_Final_Approach) do
    AI_WaitMilliSeconds(5);
  SF_CAM_TrackObj(Player);

  select := SYS_Random(3);
  if (select = 0) then
    SF_CAM_SetFollowObj(Player, -3, 2, 15);
  if (select = 1) then
    SF_CAM_SetFollowObj(Player, 3, 4, -15);
  if (select = 2) then
    SF_CAM_SetFollowObj(Player, -10, 2, 5);

  AI_WaitSeconds(30);
end;

// Player stuff

function F_InitLanding;
begin
  SF_AutopilotDisable;
  m_Event := EVENT_Land_Player;
  until (M_Event = EVENT_Activate_Landing_Cam) do AI_WaitSeconds(1);
  AI_WaitSeconds(30);
  SF_Exit;
end;

function F_PlayerTakeoff;
begin
  M_GetPos(Dauntless);
  SF_SetWorldPosition(xpos, ypos+10, zpos);
  SF_SetObjectFlag(OF_Collidable, false);
  AI_PLR_ControlAssume;
  AI_SetThrottle(0);
  AI_WaitSeconds(1);
  SF_ActivateSelf(0);
  AI_WaitSeconds(3);
  AI_SetThrottle(100);
  AI_WaitMilliSeconds(1700);
  M_Event := EVENT_Takeoff_Start;
  while (SF_GetDistance(Dauntless) < 500) do
    HCL_AI_GotoObjRelWorld_nonblock(Dauntless, 0, 15, 700);
  M_Event := EVENT_Takeoff_Complete;
  SF_SetObjectFlag(OF_Collidable, true);
  AI_PLR_ControlResume;
  SF_PlayerSwitchToCam(CamID_cockpit, Player);
  AI_WaitSeconds(10);
  M_Event := 0;
end;

function F_PlayerTakeoffFralthi;
begin
  m_Takeoff_Fralthi := 1;
  SF_SetObjectFlag(OF_Collidable, false);
  M_GetPos(Fralthi);
  SF_SetWorldPosition(xpos+85, ypos+25, zpos-120);
  AI_PLR_ControlAssume;
  AI_SetThrottle(0);
  AI_WaitSeconds(1);
  SF_ActivateSelf(0);
  AI_WaitSeconds(3);
  AI_SetThrottle(100);
  AI_WaitMilliSeconds(1700);
  M_Event := EVENT_Takeoff_Start;
  while (SF_GetDistance(Fralthi) < 500) do
    HCL_AI_GotoObjRelWorld_nonblock(Fralthi, 85, 25, -700);
//  AI_GotoObjRelWorld(Fralthi, 85, 25, -500);
  M_Event := EVENT_Takeoff_Complete;
  SF_SetObjectFlag(OF_Collidable, true);
  AI_PLR_ControlResume;
  SF_PlayerSwitchToCam(CamID_cockpit, Player);
  AI_WaitSeconds(10);
  M_Event := 0;
end;

function F_PlayerLanding;
begin
  while (SF_GetDistance(Dauntless) > 300) do AI_WaitMilliSeconds(1);
  AI_PLR_ControlAssume;
  SF_SetObjectFlag(OF_Collidable, false);
  M_Event := EVENT_Activate_Landing_Cam;
  HCL_EmptyFuel;
  AI_SetThrottle(0);
  until (SF_GetVelocityObject(Player) < 5) do
    AI_WaitMilliSeconds(1);
  AI_SetThrottle(0);

  until (m_Event = EVENT_Dauntless_Ready) do
    AI_WaitMilliSeconds(500);

  // Teleport to position relative to Dauntless
  M_GetPos(Dauntless);
  SF_SetWorldPosition(xpos, ypos, zpos-350);
  AI_FaceObject(Dauntless);
  SF_SetWorldPosition(xpos, ypos-25, zpos-350);
  AI_SetThrottle(50);
  until (SF_GetDistance(Dauntless) < 50) do AI_WaitMilliSeconds(5);
  M_Event := EVENT_Final_Approach;
  SYS_PlaySFX(SFX_Engines_Power_Down);
  AI_WaitSeconds(3);
  AI_SetThrottle(0);
  AI_WaitSeconds(5);
  SF_Exit;
end;

// Dauntless stuff

function F_DauntlessLanding;
begin
  if (SF_GetVelocityObject(Dauntless) > 0) then
  begin
    AI_SetThrottle(0);
    until (SF_GetVelocityObject(Dauntless) = 0) do AI_WaitMilliSeconds(1);
//    AI_WaitSeconds(5);
  end;

  // Teleport to position relative to NavD, face NavD
  M_GetPos(NavD);
  SF_SetWorldPosition(xpos, ypos, zpos+1000);
  AI_FaceObject(NavD);
  m_Event := EVENT_Dauntless_Ready;
  AI_WaitSeconds(25);
  SF_Exit;
end;
