//******************************************************************************
//
// Unknown Enemy
// Mission 2b - Crushing Blow
//
// Created by: Thomas Bruckner <thomas.bruckner@aon.at>
// Modified by: Jakub Majewski <qmajewski@yahoo.co.uk>
// Last modified: Apr 9th, 2004
//
//******************************************************************************

mission ue2b;

#sector: "t.sec";
#SetRooms ("cic.rom", "rec.rom");
#gfproc: "GF_Main";
#mainproc: "MAIN";

//Note: the gfproc and mainproc properties were implemented in WCPPas r24d, but do
// not work properly (which is why nobody uses r24d ;) ). These properties (in theory)
// simply tell the game which functions to use as the main mission function and the
// main gameflow function. We all know what the main mission function is (see MAIN).
// As for the main gameflow function, this is used if you want to have any functions
// in the gameplay that are NOT implemented as part of the room file. Normally, this
// property is therefore not needed. In UE, however, we used it in missions 2B, 4 and 6
// to repeatedly play the "all pilots to your ships" sound in the gameflow.
//
// In any case, if you compile this mission in WCPPas, you will find that this will
// no longer work (24c doesn't support gfproc and mainproc, but it won't crash
// or anything like that) - the gameflow function will be missing (but the MAIN function
// will work as normal).
// In order to compile this mission with the gameflow function working, do this:
// 1. Use the compile and edit option.
// 2. When the compiled mission opens, look for the FORM "PROP" containing MAIN.
// 3. Between MAIN's FORM "PROP" and the end-bracket of the preceding FORM, add this form:
// FORM "PROP"
//      {
//        CHUNK $59F32AC2
//        {
//          cstring "GF_Main"
//        }
//      }
// 4. Now use the build option. You do not need to bother saving when the
// save dialogue opens up.

#AddToSearchPath("$uesrc$");
#AddToSearchPath("$wcue$\language\");
#include wcp, consts, uepilots;
#include UE;
#include Comms;

#strings spacefli;
#strings targetid;
#strings objectiv;

#SetOutputPath("$wcue$\mission\");

#SetKillboard(PILOT_Faris, PILOT_Defender, PILOT_Ocelot, PILOT_Hellcat,
              PILOT_Night, PILOT_Doc, PILOT_Shark, PILOT_Thor,
              PILOT_Killer, PILOT_Bloodhound, PILOT_Edge, PILOT_Mage,
              PILOT_Phantom, PILOT_Gold, PILOT_Blade, PILOT_Huntress,
              PILOT_Ghost, PILOT_Gryphon, PILOT_Warrior);

var
  m_AliveEnemies,
  m_DeadEnemies,
  m_Event,
  Bombers_Left = 0,
  xpos, ypos, zpos,
  hit = 0,
  Ralari_Dead = 0;

external
  g_Fralthi_Dead,
  g_UE_2b_Won;

const
  EVENT_Takeoff_Start = 4,
  EVENT_Takeoff_Complete = 5,
  EVENT_Land_Player = 6,
  EVENT_Activate_Landing_Cam = 7,
  EVENT_Dauntless_Ready = 8,
  EVENT_Final_Approach = 9,
  EVENT_Dauntless_Dead = 10;

#name: 4;

objective mobj1
  hidden: false;
  type: MOBJ_Primary;
  text: objectiv["Destroy Inbound Fighters"];
  status: MOBJ_Incomplete;
  counter: true;
end;

objective mobj_destroy_ralari
  hidden: true;
  type: MOBJ_Primary;
  text: objectiv["Destroy Ralari"];
  status: MOBJ_Incomplete;
  counter: false;
end;

objective mobj_destroy_fralthi
  hidden: true;
  type: MOBJ_Primary;
  text: objectiv["Destroy Fralthi"];
  status: MOBJ_Incomplete;
  counter: false;
end;

object Dauntless(Capship) as "BWS Dauntless"
  obj: UE_SHIP_Dauntless;
  x: 0;
  y: 200;
  z: -500;
  main: M_Dauntless;
  death: D_Dauntless;
  direction: 180, 0, 0;
  pilot: PILOT_Dauntless;
end;

function MAIN;
begin
  MS_RunGameflow(0);
  MS_RunSpaceflight(0);
  MS_RunDebriefing;
end;

function M_BoxGenerate(ShipID, TargID); forward;

function S_EnemyFighter;
var
  target,
  a;
begin
  SF_SetObjectFlag(OF_vulnerable, 1);
  SF_SetObjectFlag(OF_alignment, ALIGN_Evil_Kilrathi);
  SF_BindToActionSphere(0);
  SF_ActivateSelf(AO_appear);
  m_AliveEnemies := m_AliveEnemies + 1;

  SF_ObjectiveIncrementTotal(mobj1);
  SF_ObjectiveIncrementTotalNeededForSuccess(mobj1);

  a := SYS_Random(5);
  if (a < 4) then AI_AddToAttackList(Dauntless, 100);
  AI_AttackEnemies;

  while (1) do begin
    AI_WaitSeconds(1);
  end;
end;

function S_EnemyFighterDeath;
begin
  m_DeadEnemies := m_DeadEnemies + 1;
  SF_ObjectiveIncrementCount(mobj1);
end;

function M_Spawn(shipId, count, x, y, z);
//
// this function spawns "count" ships of type "shipID"
// at coordinates around x, y, z
//
var
  ox, oy, oz, pilot;
begin
  while(count > 0) do begin
    ox := x + SYS_Random(600) - 300;
    oy := y + SYS_Random(600) - 300;
    oz := z + SYS_Random(600) - 300;

    pilot := 84 + SYS_Random(3);

    NAV_CreateShip(shipId, pilot, 0, @S_EnemyFighter, @S_EnemyFighterDeath, ox, oy, oz);
    AI_WaitMilliseconds(275);
    count := count - 1;
  end;
end;

function M_SpawnNearObject(shipId, count, obj);
//
// this function spawns "count" ships of type "shipID"
// at coordinates near the object given in "obj"
//
var
  x, y, z, pilot,
  ox, oy, oz;
begin
  x := SF_GetXObj(obj);
  y := SF_GetYObj(obj);
  z := SF_GetZObj(obj);

  while(count > 0) do begin
    ox := x + SYS_Random(600) + 500;
    oy := y + SYS_Random(600) + 500;
    oz := z + SYS_Random(600) + 500;

    pilot := 84 + SYS_Random(3);

    NAV_CreateShip(shipId, pilot, 0, @S_EnemyFighter, @S_EnemyFighterDeath, ox, oy, oz);
    AI_WaitMilliseconds(275);
    count := count - 1;
  end;
end;

function M_WaitUntilDead;
//
// this function waits until all enemies spawned by M_Spawn*
// have been killed.
//
begin
  until(m_DeadEnemies = m_AliveEnemies) do begin
    AI_WaitSeconds(4);
  end;
end;

function M_CountEnemies;
begin
  Result := (m_AliveEnemies - m_DeadEnemies);
end;

function M_WaitUntilDeadTimeOut(sec);
begin
  AI_WaitSeconds(5);
  SYS_TimerSet(sec - 5);
  until ((SYS_TimerGet = 0) or (M_CountEnemies = 0)) do
    AI_WaitSeconds(1);
end;

function M_GetPos(ShipID);
begin
  xpos := SF_GetXObj(ShipID);
  ypos := SF_GetYObj(ShipID);
  zpos := SF_GetZObj(ShipID);
end;

function F_InitLanding; forward;
function F_PlayerTakeoff; forward;
function F_PlayerLanding; forward;
function F_DauntlessLanding; forward;


// ************************* Dauntless NAV *************************

object NavD(Navpoint)
  x: 0;
  y: 0;
  z: 0;
  main: M_NavD;
  name: spacefli["Dauntless Nav"];
  navdata: 1, 250000;
end;

object Player(Player)
  obj: UE_SHIP_Scimitar;
  x: 0;
  y: 0;
  z: 800;
  main: M_Player;
  direction: 180, 0, 0;
  pilot: PILOT_Casey1;
end;

object Belt1(ABStart)
  x: 0;
  y: 2750;
  z: 2500;
  absdata: 1, 200, 2000;
end;

object Fralthi(Capship) as "Fralthi"
  obj: UE_SHIP_Fralthi;
  x: -1100;
  y: 200;
  z: 2700;
  main: M_Fralthi;
  death: D_Fralthi;
  direction: 180, 0, 0;
  pilot: PILOT_Kat_Capship;
end;

object Ralari(Capship) as "Ralari"
  obj: UE_SHIP_Ralari;
  x: 1100;
  y: 200;
  z: 2500;
  main: M_Ralari;
  death: D_Ralari;
  direction: 180, 0, 0;
  pilot: PILOT_Kat_Capship;
end;

function M_Alpha; forward;
function D_Alpha; forward;
function M_Beta; forward;
function D_Beta; forward;
function M_Charlie; forward;
function D_Charlie; forward;

function M_NavD;
var
  setup = true;
begin
  NAV_SetEjectSequence(ES_alien_pickup_MIA);
  while(1) do begin
    if (NAV_WithinSphere(Player)) then begin
      NAV_ActivateSelf;

      if (setup) then begin
        //let's activate the Dauntless and Alpha Wing
        //Wing: 4 Scimitars (Alpha 2: Sprite, Alpha 3:
        //      Defender, Alpha 4: Foxtrot, Alpha 5: Indigo)
        //SF_ActivateObject(Dauntless, AO_appear);
        NAV_CreateShip(UE_SHIPID_Scimitar, PILOT_Faris, 1, @M_Alpha, @D_Alpha, 100, 0, 100);
        NAV_CreateShip(UE_SHIPID_Scimitar, PILOT_Defender, 1, @M_Alpha, @D_Alpha, 100, 0, 200);
        NAV_CreateShip(UE_SHIPID_Scimitar, PILOT_Ocelot, 1, @M_Alpha, @D_Alpha, -100, 0, 300);
        NAV_CreateShip(UE_SHIPID_Scimitar, PILOT_Hellcat, 1, @M_Alpha, @D_Alpha, -100, 0, 400);

        // Enemy Forces:
        // 4 Gratha Bombers(Kilrathi Aces),
        // 4 Dralthi (Kilrathi Pilots)
        M_Spawn(UE_SHIPID_Gratha_Bomber, 6, 0, 1000, 3000);
        M_Spawn(UE_SHIPID_Dralthi, 4, 0, 2000, 2500);

        M_BoxGenerate(Dauntless, Fralthi);
        AI_WaitSeconds(1);
        M_BoxGenerate(Dauntless, Ralari);
        AI_WaitSeconds(1);
        M_BoxGenerate(Fralthi, Dauntless);
        AI_WaitSeconds(1);
        M_BoxGenerate(Ralari, Dauntless);
        AI_WaitSeconds(1);

        // Wave 2 (two minutes after take-off)
        // 4 Gratha Bombers (Kilrathi Aces),
        // 8 Salthi (Kilrathi Pilots)
        AI_WaitSeconds(16);
        NAV_CreateShip(UE_SHIPID_Banshee, PILOT_Shark, targetid["Bravo 1"], @M_Beta, @D_Beta, 0, 350, 400);
        NAV_CreateShip(UE_SHIPID_Epee, PILOT_Huntress, targetid["Bravo 2"], @M_Beta, @D_Beta, 0, 300, 450);

        M_WaitUntilDeadTimeOut(50);

        M_Spawn(UE_SHIPID_Gratha_Bomber, 5, 0, 1000, 2000);
        M_Spawn(UE_SHIPID_Salthi, 8, 0, 2000, 2500);

        NAV_CreateShip(UE_SHIPID_Banshee, PILOT_Gryphon, targetid["Bravo 3"], @M_Beta, @D_Beta, 0, 350, 400);

        // Wave 3 (four minutes after take-off)
        // 4 Vaktoth Fighters (Kilrathi Aces),
        // 4 Dralthi (Kilrathi Pilots)
        // Ralari (Kilrathi Corvette Pilot, 82),
        // Fralthi (Kilrathi Corvette Pilot, 82)

        M_WaitUntilDeadTimeOut(120);

        SF_ActivateObject(Fralthi, AO_appear);
        SF_ActivateObject(Ralari, AO_appear);
        SF_ObjectiveEnable(mobj_destroy_fralthi);
        SF_ObjectiveEnable(mobj_destroy_ralari);


        M_Spawn(UE_SHIPID_Vaktoth_Fighter, 2, 0, 1000, 3000);
        M_Spawn(UE_SHIPID_Vaktoth_Bomber, 3, 0, 1000, 2500);

        NAV_CreateShip(UE_SHIPID_Epee, PILOT_Mage, targetid["Bravo 4"], @M_Beta, @D_Beta, 0, 300, 450);

        AI_WaitSeconds(25);
        M_Spawn(UE_SHIPID_Dralthi, 4, 0, 3000, 3000);

        NAV_CreateShip(UE_SHIPID_Epee, PILOT_Doc, targetid["Charlie 1"], @M_Charlie, @D_Charlie, 0, 350, 400);
        NAV_CreateShip(UE_SHIPID_Epee, PILOT_Night, targetid["Charlie 2"], @M_Charlie, @D_Charlie, 0, 300, 450);

        AI_WaitSeconds(20);
        NAV_CreateShip(UE_SHIPID_Scimitar_Bomber, PILOT_Mage, targetid["Charlie 3"], @M_Charlie, @D_Charlie, 0, 350, 400);

        // Wave 4 (five minutes after take-off; this one should appear to
        // be launched from the Fralthi; if the Fralthi is dead, then this
        // wave doesn't come)
        // 4 Vaktoth Fighters (Kilrathi Aces),
        // 4 Gratha Fighters (Kilrathi Aces)

        NAV_CreateShip(UE_SHIPID_Scimitar_Bomber, PILOT_Gold, targetid["Charlie 4"], @M_Charlie, @D_Charlie, 0, 300, 400);
        NAV_CreateShip(UE_SHIPID_Epee, PILOT_Edge, targetid["Charlie 5"], @M_Charlie, @D_Charlie, 0, 350, 450);

        M_WaitUntilDeadTimeOut(100);

        if (g_Fralthi_Dead = false) then begin
          M_SpawnNearObject(UE_SHIPID_Vaktoth_Fighter, 2, Fralthi);
          AI_WaitSeconds(15);
        end;
        if (g_Fralthi_Dead = false) then begin
          M_SpawnNearObject(UE_SHIPID_Vaktoth_Fighter, 2, Fralthi);
          AI_WaitSeconds(25);
        end;
        if (g_Fralthi_Dead = false) then begin
          M_SpawnNearObject(UE_SHIPID_Gratha_Bomber, 2, Fralthi);
          AI_WaitSeconds(25);
        end;
        if (g_Fralthi_Dead = false) then begin
          M_SpawnNearObject(UE_SHIPID_Gratha_Bomber, 2, Fralthi);
          AI_WaitSeconds(25);
        end;

        M_WaitUntilDead;
        NAV_SetEjectSequence(ES_SAR_pickup);

        SF_SetMissionSuccess;
        g_UE_2b_Won := true;

        setup := false;

        AI_WaitSeconds(8);
        // now landing
        F_InitLanding;

        //while(1) do
        //  AI_WaitSeconds(1);
        AI_WaitSeconds(60);
        SF_Exit;
      end;

      while(NAV_WithinSphere(Player)) do begin
        AI_WaitSeconds(1);
      end;
      NAV_DeactivateSelf;
    end;
    AI_WaitSeconds(1);
  end;
end;

function M_Player;
begin
  SF_SetObjectFlag(OF_Alignment, ALIGN_CONFED);
  SF_BindToActionSphere(0);
  SF_SetBaseShip(Dauntless);
  F_PlayerTakeoff;

  while (1) do begin
    if (m_Event = EVENT_Land_Player) then
      F_PlayerLanding;

    if (m_Event = EVENT_Dauntless_Dead) then begin
      AI_WaitSeconds(10);
      SF_ExitEndGame(2);
    end;

    AI_WaitSeconds(1);
  end;
end;

function M_Alpha;
begin
  SF_SetObjectFlag(OF_alignment, ALIGN_Confed);
  SF_BindToActionSphere(0);
  SF_ActivateSelf(0);
  AI_AddToWing(Player);

  while(1) do begin
    AI_WaitSeconds(1);
    if ((m_Event = EVENT_Land_Player) or (m_Event = EVENT_Activate_Landing_Cam)) then
      AI_RemoveFromWing;
  end;
end;

function D_Alpha;
begin
end;

function M_Beta;
begin
  SF_SetObjectFlag(OF_alignment, ALIGN_Confed);
  SF_BindToActionSphere(0);
  SF_ActivateSelf(0);
  AI_AddToWing(Player);

  AI_SendComm(COMM_Leader_Report_Arriving);

  while(1) do begin
    if ((m_Event = EVENT_Land_Player) or (m_Event = EVENT_Activate_Landing_Cam)) then
      AI_RemoveFromWing;
    AI_WaitSeconds(1);
  end;
end;

function D_Beta;
begin
end;

function M_Charlie;
begin
  Bombers_Left := Bombers_Left + 1;
  SF_SetObjectFlag(OF_alignment, ALIGN_Confed);
  SF_BindToActionSphere(0);
  SF_ActivateSelf(0);

  AI_SendComm(COMM_Leader_Report_Arriving);

  AI_AddToAttackList(Fralthi, 300);
  AI_AddToAttackList(Ralari, 300);
  //AI_AttackEnemies;

  while(1) do begin
    AI_ReplenishMissilesAndFuel;
    if ((m_Event = EVENT_Land_Player) or (m_Event = EVENT_Activate_Landing_Cam)) then
      AI_RemoveFromWing;
    SF_SetObjectFlag(OF_vulnerable, false);
    AI_WaitSeconds(5);
    AI_ReplenishMissilesAndFuel;
    if (Bombers_Left > 3) then begin
      SF_SetObjectFlag(OF_vulnerable, true);
      AI_WaitSeconds(4);
    end;
  end;
end;

function D_Charlie;
begin
  Bombers_Left := Bombers_Left + 1;
end;

function M_Dauntless;
begin
  SF_SetPilotImmortal(PILOT_Gryphon, 1);
  SF_SetPilotImmortal(PILOT_Gold, 1);
  SF_SetPilotImmortal(PILOT_Mage, 1);
  SF_SetPilotImmortal(PILOT_Night, 1);
  SF_SetPilotImmortal(PILOT_Phantom, 1);
  SF_SetPilotImmortal(PILOT_Defender, 1);
  SF_SetPilotImmortal(PILOT_Faris, 1);
  SF_SetPilotImmortal(PILOT_Huntress, 1);
  SF_SetPilotImmortal(PILOT_Hellcat, 1);
  SF_SetPilotImmortal(PILOT_Warrior, 1);
  SF_SetPilotImmortal(PILOT_Ocelot, 1);
  SF_SetPilotImmortal(PILOT_Doc, 1);
  SF_SetPilotImmortal(PILOT_Edge, 1);
  SF_SetPilotImmortal(PILOT_Shark, 1);
  SF_SaveObjectState(true);
  SF_ActivateSelf(0);

  SF_SetObjectFlag(OF_alignment, ALIGN_Confed);
  SF_BindToActionSphere(0);

  AI_SetThrottle(20);

  AI_WaitSeconds(6);
  AI_SendComm(COMM_Pilot_Report_Enemies_Inbound);

  while(1) do begin
    if (g_UE_2b_Won = true) then begin
      AI_WaitSeconds(3);
      AI_SendSpecialComm(22, 1);
      AI_WaitSeconds(2);
      AI_SendSpecialComm(22, 2);
      until (m_Event = EVENT_Activate_Landing_Cam) do AI_WaitMilliSeconds(1);
      F_DauntlessLanding;
    end;
    AI_SetThrottle(0);
    AI_WaitMilliSeconds(1);
  end;
end;

function D_Dauntless;
begin
  //m_Event := EVENT_Dauntless_Dead;
end;

function M_Fralthi;
begin
  AI_WaitUntilActive;
  m_AliveEnemies := m_AliveEnemies + 1;

  SF_SetObjectFlag(OF_alignment, ALIGN_Evil_Kilrathi);
  SF_BindToActionSphere(0);

  //AI_FaceObject(Dauntless);
  AI_SetThrottle(5);

  while(1) do begin
    while (SF_GetZ > -1000) do
      HCL_AI_GotoObjRelWorld_nonblock(Fralthi, 0, 0, -1100);
    AI_SetThrottle(0);
    AI_WaitSeconds(1);
  end;
end;

function D_Fralthi;
begin
  m_DeadEnemies := m_DeadEnemies + 1;
  g_Fralthi_Dead := true;
  SF_ObjectiveSetComplete(mobj_destroy_fralthi);
  AI_SetThrottle(0);
end;

function M_Ralari;
begin
  AI_WaitUntilActive;
  m_AliveEnemies := m_AliveEnemies + 1;

  SF_SetObjectFlag(OF_alignment, ALIGN_Evil_Kilrathi);
  SF_BindToActionSphere(0);

  //AI_FaceObject(Dauntless);
  AI_SetThrottle(50);

  while(1) do begin
    while (SF_GetZ > -1000) do
      HCL_AI_GotoObjRelWorld_nonblock(Ralari, 0, 0, -1100);
    AI_SetThrottle(0);
    AI_WaitSeconds(1);
  end;
end;

function D_Ralari;
begin
  m_DeadEnemies := m_DeadEnemies + 1;
  SF_ObjectiveSetComplete(mobj_destroy_ralari);
  AI_SetThrottle(0);
  Ralari_Dead := true;
end;



// **************** Takeoff/Landing routines **************
// ********************************************************
// Camera stuff

object Camera(Camera)
  x: 0;
  y: 0;
  z: 0;
  main: M_Camera;
end;

function F_Takeoff(select); forward;
function F_Landing(select); forward;

function M_Camera;
begin
  while(1) do
  begin
    if (m_Event = EVENT_Takeoff_Start) then
      F_Takeoff(SYS_Random(3));
    if (m_Event = EVENT_Activate_Landing_Cam) then
      F_Landing(SYS_Random(3));
    AI_WaitMilliSeconds(15);
  end;
end;

function F_Takeoff(select);
begin
  SF_CAM_TrackObj(Player);

  if (select = 0) then
    SF_CAM_SetFollowObj(Player, -30, 35, -40);
  if (select = 1) then
    SF_CAM_SetFollowObj(Player, -10, 35, 80);
  if (select = 2) then
    SF_CAM_SetFollowObj(Player, 0, 5, 40);

  SF_ActivateSelf(0);
  until (m_Event = EVENT_Takeoff_Complete) do
    AI_WaitSeconds(1);
  SF_CAM_TrackNothing;
  SF_DeactivateSelf(0);
end;

function F_Landing(select);
begin
  SF_CAM_HideDust;
  SF_CAM_TrackObj(NavD);
  SF_CAM_SetFollowObj(NavD, 0, 1, 0);
  SF_ActivateSelf(0);
  while (m_Event <> EVENT_Dauntless_Ready) do
    AI_WaitMilliSeconds(1);
  SF_CAM_TrackObj(Dauntless);

  if (select = 0) then
    SF_CAM_SetFollowObj(Dauntless, -200, 200, -350);
  if (select = 1) then
    SF_CAM_SetFollowObj(Dauntless, -50, 200, 500);
  if (select = 2) then
    SF_CAM_SetFollowObj(Dauntless, 400, 100, 300);

  until (m_Event = EVENT_Final_Approach) do
    AI_WaitMilliSeconds(5);
  SF_CAM_TrackObj(Player);

  select := SYS_Random(3);
  if (select = 0) then
    SF_CAM_SetFollowObj(Player, -3, 2, 15);
  if (select = 1) then
    SF_CAM_SetFollowObj(Player, 3, 4, -15);
  if (select = 2) then
    SF_CAM_SetFollowObj(Player, -9, 2, 5);

  AI_WaitSeconds(30);
end;

// Player stuff

function F_InitLanding;
begin
  SF_AutopilotDisable;
  m_Event := EVENT_Land_Player;
  until (M_Event = EVENT_Activate_Landing_Cam) do AI_WaitSeconds(1);
  AI_WaitSeconds(30);
  SF_Exit;
end;

function F_PlayerTakeoff;
begin
  M_GetPos(Dauntless);
  SF_SetWorldPosition(xpos+15, ypos-25, zpos);
  SF_SetObjectFlag(OF_Collidable, false);
  AI_PLR_ControlAssume;
  AI_SetThrottle(0);
  AI_WaitSeconds(1);
  SF_ActivateSelf(0);
  AI_WaitSeconds(2);
  AI_SetThrottle(100);
  AI_WaitMilliSeconds(1700);
  M_Event := EVENT_Takeoff_Start;
  while (SF_GetDistance(Dauntless) < 450) do
    HCL_AI_GotoObjRelWorld_nonblock(Dauntless, 15, -20, -600);
  M_Event := EVENT_Takeoff_Complete;
  SF_SetObjectFlag(OF_Collidable, true);
  AI_PLR_ControlResume;
  SF_PlayerSwitchToCam(CamID_cockpit, Player);
  AI_WaitSeconds(10);
  M_Event := 0;
end;

function F_PlayerLanding;
begin
  while (SF_GetDistance(Dauntless) > 300) do AI_WaitMilliSeconds(1);
  AI_PLR_ControlAssume;
  SF_SetObjectFlag(OF_Collidable, false);
  M_Event := EVENT_Activate_Landing_Cam;
  HCL_EmptyFuel;
  AI_SetThrottle(0);
  until (SF_GetVelocityObject(Player) < 5) do
    AI_WaitMilliSeconds(1);
  AI_SetThrottle(0);

  until (m_Event = EVENT_Dauntless_Ready) do
    AI_WaitMilliSeconds(500);

  // Teleport to position relative to Dauntless
  M_GetPos(Dauntless);
  SF_SetWorldPosition(xpos, ypos, zpos-350);
  AI_FaceObject(Dauntless);
  SF_SetWorldPosition(xpos, ypos-25, zpos-350);
  AI_SetThrottle(50);
  until (SF_GetDistance(Dauntless) < 50) do AI_WaitMilliSeconds(5);
  M_Event := EVENT_Final_Approach;
  SYS_PlaySFX(SFX_Engines_Power_Down);
  AI_WaitSeconds(3);
  AI_SetThrottle(0);
  AI_WaitSeconds(5);
  SF_Exit;
end;

// Dauntless stuff

function F_DauntlessLanding;
begin
  if (SF_GetVelocityObject(Dauntless) > 0) then
  begin
    AI_SetThrottle(0);
    AI_WaitSeconds(5);
  end;

  // Teleport to position relative to NavD, face NavD
  M_GetPos(NavD);
  SF_SetWorldPosition(xpos, ypos, zpos+3000);
  AI_FaceObject(NavD);
  m_Event := EVENT_Dauntless_Ready;
  AI_WaitSeconds(25);
  SF_Exit;
end;

function M_BoxGenerate(ShipID, TargID);
var
  ox, oy, oz;
begin
  //The battle takes place around the Dauntless
  m_GetPos(Dauntless);
  oy := ypos;
  oz := zpos - 100;

  // But we use the D's position for tubes from both ships
  if (TargID = Fralthi) then
    ox := xpos - 100;
  if (TargID = Ralari) then
    ox := xpos + 100;
  if (TargID = Dauntless) then
  begin
    if (ShipID = Fralthi) then
      ox := xpos - 1000
    else
      ox := xpos + 1050;
  end;

  if (TargID = Fralthi) then begin
    NAV_CreateShip(UE_SHIPID_Box, PILOT_Confed, 1, @M_Tube_D_F, @D_Tube, ox, 150, oz);
    oz := oz + 100;
    NAV_CreateShip(UE_SHIPID_Box, PILOT_Confed, 1, @M_Tube_D_F, @D_Tube, ox, 250, oz);
    oz := oz + 100;
    NAV_CreateShip(UE_SHIPID_Box, PILOT_Confed, 1, @M_Tube_D_F, @D_Tube, ox, 150, oz);
  end;

  if (TargID = Ralari) then begin
    NAV_CreateShip(UE_SHIPID_Box, PILOT_Confed, 1, @M_Tube_D_R, @D_Tube, ox, 150, oz);
    oz := oz + 100;
    NAV_CreateShip(UE_SHIPID_Box, PILOT_Confed, 1, @M_Tube_D_R, @D_Tube, ox, 250, oz);
    oz := oz + 100;
    NAV_CreateShip(UE_SHIPID_Box, PILOT_Confed, 1, @M_Tube_D_R, @D_Tube, ox, 150, oz);
  end;

  if ((TargID = Dauntless) and (ShipID = Fralthi)) then begin
    NAV_CreateShip(UE_SHIPID_Box, PILOT_Confed, 1, @M_Tube_F_D, @D_Tube, ox, 250, oz);
    oz := oz + 100;
    NAV_CreateShip(UE_SHIPID_Box, PILOT_Confed, 1, @M_Tube_F_D, @D_Tube, ox, 250, oz);
    oz := oz + 100;
    NAV_CreateShip(UE_SHIPID_Box, PILOT_Confed, 1, @M_Tube_F_D, @D_Tube, ox, 250, oz);
  end;

  if ((TargID = Dauntless) and (ShipID = Ralari)) then begin
    NAV_CreateShip(UE_SHIPID_Box, PILOT_Confed, 1, @M_Tube_R_D, @D_Tube, ox, 175, oz);
    oz := oz + 100;
    NAV_CreateShip(UE_SHIPID_Box, PILOT_Confed, 1, @M_Tube_R_D, @D_Tube, ox, 175, oz);
    oz := oz + 100;
    NAV_CreateShip(UE_SHIPID_Box, PILOT_Confed, 1, @M_Tube_R_D, @D_Tube, ox, 175, oz);
  end;
end;

function M_Tube_D_F;
begin
  SF_SetObjectFlag (OF_alignment, ALIGN_Neutral);
  SF_BindToActionSphere(0);
  AI_IgnoreCollisions(1);
  SF_SetObjectFlag (OF_collidable, false);
  until (SF_GetZObj(Fralthi) < (SF_GetZObj(Dauntless)-50)) do AI_WaitMilliSeconds(1); //(fire = true) do AI_WaitMilliSeconds(1);
  AI_WaitSeconds(2);
  AI_FaceObject(Fralthi);
  SF_ActivateSelf(0);
  if (SF_GetActiveStatus(Dauntless) = AS_Active) then AI_FireMissile(6);
  AI_WaitSeconds(1);
  AI_FaceObject(Fralthi);
  AI_ReplenishMissilesAndFuel;
  if (SF_GetActiveStatus(Dauntless) = AS_Active) then AI_FireMissile(6);
  AI_WaitSeconds(1);
  AI_FaceObject(Fralthi);
  AI_ReplenishMissilesAndFuel;
  if (SF_GetActiveStatus(Dauntless) = AS_Active) then AI_FireMissile(6);
  AI_WaitSeconds(1);
  AI_FaceObject(Fralthi);
  AI_ReplenishMissilesAndFuel;
  if (SF_GetActiveStatus(Dauntless) = AS_Active) then AI_FireMissile(6);
  if ((SF_GetActiveStatus(Fralthi) = AS_Active) and (SF_GetActiveStatus(Dauntless) = AS_Active)) then begin
    AI_WaitSeconds(8);
    SF_DestroyObject(Fralthi);
  end;
  SF_DeactivateSelf(0);
  while(1) do
  AI_WaitSeconds(1);
end;

function M_Tube_D_R;
begin
  SF_SetObjectFlag (OF_alignment, ALIGN_Neutral);
  SF_BindToActionSphere(0);
  AI_IgnoreCollisions(1);
  SF_SetObjectFlag (OF_collidable, false);
  until (SF_GetZObj(Ralari) < (SF_GetZObj(Dauntless)+350)) do AI_WaitMilliSeconds(1); //(fire = true) do AI_WaitMilliSeconds(1);
  AI_WaitSeconds(2);
  AI_FaceObject(Ralari);
  SF_ActivateSelf(0);
  if (SF_GetActiveStatus(Dauntless) = AS_Active) then AI_FireMissile(6);
  AI_WaitSeconds(1);
  AI_FaceObject(Ralari);
  AI_ReplenishMissilesAndFuel;
  if (SF_GetActiveStatus(Dauntless) = AS_Active) then AI_FireMissile(6);
  AI_WaitSeconds(1);
  AI_FaceObject(Ralari);
  AI_ReplenishMissilesAndFuel;
  if (SF_GetActiveStatus(Dauntless) = AS_Active) then AI_FireMissile(6);
  AI_WaitSeconds(1);
  AI_FaceObject(Ralari);
  AI_ReplenishMissilesAndFuel;
  if (SF_GetActiveStatus(Dauntless) = AS_Active) then AI_FireMissile(6);
  if ((SF_GetActiveStatus(Ralari) = AS_Active) and (SF_GetActiveStatus(Dauntless) = AS_Active)) then begin
    AI_WaitSeconds(8);
    SF_DestroyObject(Ralari);
  end;
  SF_DeactivateSelf(0);
  while(1) do
  AI_WaitSeconds(1);
end;

function M_Tube_F_D;
begin
  SF_SetObjectFlag (OF_alignment, ALIGN_Neutral);
  SF_BindToActionSphere(0);
  AI_IgnoreCollisions(1);
  SF_SetObjectFlag (OF_collidable, false);
  until (SF_GetZObj(Fralthi) < (SF_GetZObj(Dauntless)+100)) do AI_WaitMilliSeconds(1); //(fire = true) do AI_WaitMilliSeconds(1);
  AI_WaitSeconds(1);
  AI_FaceObject(Dauntless);
  AI_WaitSeconds(1);
  SF_ActivateSelf(0);
  if (g_Fralthi_Dead = false) then begin
    if (SF_GetActiveStatus(Fralthi) = AS_Active) then AI_FireMissile(6);
    AI_WaitSeconds(1);
    AI_ReplenishMissilesAndFuel;
    if (SF_GetActiveStatus(Fralthi) = AS_Active) then AI_FireMissile(6);
    AI_WaitSeconds(1);
    AI_ReplenishMissilesAndFuel;
    if (SF_GetActiveStatus(Fralthi) = AS_Active) then AI_FireMissile(6);
    AI_WaitSeconds(1);
    AI_ReplenishMissilesAndFuel;
    if (SF_GetActiveStatus(Fralthi) = AS_Active) then AI_FireMissile(6);
    if (SF_GetActiveStatus(Dauntless) = AS_Active) then begin
      if ((SF_GetNumComponentPartsObj(Fralthi, PART_ChildBridge) + SF_GetNumComponentPartsObj(Fralthi, PART_ChildEngine)) = 3) then begin
        hit := hit + 1;
        if (hit = 6) then SF_DestroyObject(Dauntless);
      end;
    end;
  end;
  SF_DeactivateSelf(0);
  while(1) do
  AI_WaitSeconds(1);
end;

function M_Tube_R_D;
begin
  SF_SetObjectFlag (OF_alignment, ALIGN_Neutral);
  SF_BindToActionSphere(0);
  AI_IgnoreCollisions(1);
  SF_SetObjectFlag (OF_collidable, false);
  until (SF_GetZObj(Ralari) < (SF_GetZObj(Dauntless)+100)) do AI_WaitMilliSeconds(1); //(fire = true) do AI_WaitMilliSeconds(1);
  AI_WaitSeconds(1);
  AI_FaceObject(Dauntless);
  AI_WaitSeconds(1);
  SF_ActivateSelf(0);
  if (Ralari_Dead = false) then begin
    if (SF_GetActiveStatus(Ralari) = AS_Active) then AI_FireMissile(6);
    AI_WaitSeconds(1);
    AI_ReplenishMissilesAndFuel;
    if (SF_GetActiveStatus(Ralari) = AS_Active) then AI_FireMissile(6);
    AI_WaitSeconds(1);
    AI_ReplenishMissilesAndFuel;
    if (SF_GetActiveStatus(Ralari) = AS_Active) then AI_FireMissile(6);
    AI_WaitSeconds(1);
    AI_ReplenishMissilesAndFuel;
    if (SF_GetActiveStatus(Ralari) = AS_Active) then AI_FireMissile(6);
    if (SF_GetActiveStatus(Dauntless) = AS_Active) then begin
      if ((SF_GetNumComponentPartsObj(Ralari, PART_ChildBridge) + SF_GetNumComponentPartsObj(Ralari, PART_ChildEngine)) = 3) then begin
        hit := hit + 1;
        if (hit = 6) then SF_DestroyObject(Dauntless);
      end;
    end;
  end;
  SF_DeactivateSelf(0);
  while(1) do
  AI_WaitSeconds(1);
end;

function D_Tube;
begin
end;


function GF_Main;
begin
  SYS_TimerSet(5);
  while (1) do begin
    if (SYS_TimerGet = 0) then begin
      SYS_PlaySFX(UE_SFX_Scramble);
      SYS_TimerSet(20);
    end;
    GF_Exit;
  end;
end;
