//******************************************************************************
//
//      Unknown Enemy
//      Mission 4 - Scramble 1
//
//      Created by Alex Barnfield  <alex@crius.net>
//                 Jakub Majewski  <qmajewski@yahoo.co.uk>
//                 Thomas Bruckner <thomas.bruckner@aon.at>
//
//      Last Modified Apr 9th 2004
//
//******************************************************************************


mission ue4;

#AddToSearchPath("$wcue$\language\");
#AddToSearchPath("$uesrc$");

#include wcp, consts, ships, uepilots, UE, comms;

#strings targetid, objectiv;

#SetRooms ("cic.rom", "rec.rom");
#gfproc: "GF_Main";
#mainproc: "MAIN";

//Note: the gfproc and mainproc properties were implemented in WCPPas r24d, but do
// not work properly (which is why nobody uses r24d ;) ). These properties (in theory)
// simply tell the game which functions to use as the main mission function and the
// main gameflow function. We all know what the main mission function is (see MAIN).
// As for the main gameflow function, this is used if you want to have any functions
// in the gameplay that are NOT implemented as part of the room file. Normally, this
// property is therefore not needed. In UE, however, we used it in missions 2B, 4 and 6
// to repeatedly play the "all pilots to your ships" sound in the gameflow.
//
// In any case, if you compile this mission in WCPPas, you will find that this will
// no longer work (24c doesn't support gfproc and mainproc, but it won't crash
// or anything like that) - the gameflow function will be missing (but the MAIN function
// will work as normal).
// In order to compile this mission with the gameflow function working, do this:
// 1. Use the compile and edit option.
// 2. When the compiled mission opens, look for the FORM "PROP" containing MAIN.
// 3. Between MAIN's FORM "PROP" and the end-bracket of the preceding FORM, add this form:
// FORM "PROP"
//      {
//        CHUNK $59F32AC2
//        {
//          cstring "GF_Main"
//        }
//      }
// 4. Now use the build option. You do not need to bother saving when the
// save dialogue opens up.

#SetOutputPath("$wcue$\mission\");

//*************Main Program**********


#sector: "t.sec";

#name: 8;

#SetKillboard(PILOT_Faris, PILOT_Defender, PILOT_Ocelot, PILOT_Hellcat,
              PILOT_Night, PILOT_Doc, PILOT_Shark, PILOT_Thor,
              PILOT_Killer, PILOT_Bloodhound, PILOT_Edge, PILOT_Mage,
              PILOT_Phantom, PILOT_Gold, PILOT_Blade, PILOT_Huntress,
              PILOT_Ghost, PILOT_Gryphon, PILOT_Warrior);


var killcount, comm1check=0, m_Event, x, y, z, D_Dead = 0;

const
  EVENT_Takeoff_Start = 4,
  EVENT_Takeoff_Complete = 5,
  EVENT_Land_Player = 6,
  EVENT_Activate_Landing_Cam = 7,
  EVENT_Dauntless_Ready = 8,
  EVENT_Final_Approach = 9;

external g_Fralthi_Dead, g_UE_3a_Won, g_UE_3b_Won;


objective mobj_Defend
  hidden: false;
  type: MOBJ_Primary;
  text: objectiv["Defend the Dauntless"];
  status: MOBJ_Incomplete;
  counter: false;
end;


object Player(Player)
  obj: scim;
  x: 0;
  y: -50;
  z: 1600;
  main: M_Player;
  pilot: PILOT_Casey1;
end;


object Dauntless(Capship) as "BWS Dauntless"
  obj: UE_SHIP_Dauntless;
  x: 0;
  y: 0;
  z: 0;
  main: M_Dauntless;
  pilot: PILOT_Dauntless;
  death: D_Dauntless;
end;

object Fralthi_(capship) as "HRS Zu'Baka"
  obj: UE_SHIP_Fralthi;
  x: -400;
  y: 500;
  z: -400;
  main: M_Fralthi;
  direction: 30, 60, 80;
  pilot: PILOT_Fralthi;
end;

object NavD(navpoint)
  x: 0;
  y: 0;
  z: 0;
  main: M_DNav;
  navdata: 1, 5000;
end;


object Edge(ship)
  obj: scim;
  x: 0;
  y: 400;
  z: 0;
  main: M_Wingmen;
  targstr: 1;
  pilot: PILOT_Edge;
end;


object Ocelot(ship)
  obj: scim;
  x: -100;
  y: 400;
  z: 0;
  main: M_Wingmen;
  targstr: 1;
  pilot: PILOT_Ocelot;
end;


object Phantom(ship)
  obj: scim;
  x: 100;
  y: 400;
  z: 0;
  main: M_scim;
  targstr: 1;
  pilot: PILOT_Phantom;
end;


object Hellcat(ship)
  obj: scim;
  x: 200;
  y: 400;
  z: 0;
  main: M_scim;
  targstr: 1;
  pilot: PILOT_Hellcat;
end;

object Faris(ship)
  obj: epee;
  x: 0;
  y: -20;
  z: 20;
  main: M_EpeeLead;
  targstr: 1;
  pilot: PILOT_Faris;
end;


object Gold(ship)
  obj: epee;
  x: 15;
  y: -20;
  z: 20;
  main: M_Epee;
  targstr: 1;
  pilot: PILOT_Gold;
end;


object Mage(ship)
  obj: epee;
  x: -15;
  y: -20;
  z: 20;
  main: M_Epee;
  targstr: 1;
  pilot: PILOT_Mage;
end;


function F_InitLanding; forward;
function F_PlayerTakeoff; forward;
function F_PlayerLanding; forward;
function F_DauntlessLanding; forward;


function MAIN;
begin
 MS_RunGameflow(0);
 MS_RunSpaceFlight(0);
 MS_RunDebriefing;
end;


function M_GetPos(ShipID);
begin
  x := SF_GetXObj(ShipID);
  y := SF_GetYObj(ShipID);
  z := SF_GetZObj(ShipID);
end;


function M_Player;
begin
  SF_SetObjectFlag (OF_Alignment, ALIGN_Confed);
  SF_SetBaseShip(Dauntless);
  SF_ActivateSelf(0);
  SF_SubHitPoints(30);
  F_PlayerTakeoff;
  while (1) do begin
    if (m_Event = EVENT_Land_Player) then
      F_PlayerLanding;
    AI_WaitSeconds(1);
    if (D_Dead) then begin
      AI_WaitSeconds(10);
      SF_ExitEndGame(2);
    end;
  end;
end;


function M_Dauntless;
begin
  AI_WaitUntilActive;
//  SF_SaveObjectState(-1);
  SF_SetObjectFlag (OF_Alignment, ALIGN_Confed);
  //SF_ActivateSelf(0);
  SF_BindToActionSphere(1);
  //if ((g_UE_3a_Won = 0) and (g_UE_3b_Won = 0)) then
  //  SF_SetChildObjectVulnerable(Dauntless, PART_ChildEngine, false);
  SF_SetPilotImmortal(PILOT_Gold, 1);
  SF_SetPilotImmortal(PILOT_Mage, 1);
  SF_SetPilotImmortal(PILOT_Faris, 1);
  SF_SetPilotImmortal(PILOT_Phantom, 1);
  SF_SetPilotImmortal(PILOT_Hellcat, 1);
  SF_SetPilotImmortal(PILOT_Edge, 1);
  SF_SetPilotImmortal(PILOT_Ocelot, 1);
  AI_Waitseconds(40);
  AI_SendSpecialComm(24, 0);
  AI_Waitseconds(7);

  until (comm1check=1) do
    AI_Waitseconds(1);

  AI_SendSpecialComm(24, 1);
  comm1check:=0;

  while(1) do begin
    AI_WaitMilliSeconds(1);
    if (m_Event = EVENT_Activate_Landing_Cam) then begin
      if ((g_UE_3a_Won) or (g_UE_3b_Won)) then
        SF_SaveObjectState(true);
      //else
        //SF_SaveObjectState(-1);
      F_DauntlessLanding;
      AI_WaitMilliseconds(1);
    end;
  end;
end;

function M_Wingmen;
begin
  SF_SetObjectFlag (OF_Alignment, ALIGN_Confed);
  SF_ActivateSelf(0);
  AI_Waitseconds(1);
  SF_SubHitPoints(30);
  until (M_Event = EVENT_Takeoff_Complete) do
    AI_WaitMilliSeconds(1);
  AI_AddToWing(Player);

  while(1) do begin
    if (m_Event = EVENT_Land_Player) then begin
      AI_RemoveFromWing;
      AI_IgnoreCollisions(1);
      AI_AttackNothing(1);
      AI_SetThrottle(0);
    end;
    AI_WaitMilliseconds(100);
  end;
end;

function M_EpeeLead;
begin
  SF_SetObjectFlag (OF_Alignment, ALIGN_Confed);
  AI_Waitseconds(45);
  AI_Attacknothing(1);
  SF_ActivateSelf(0);
  AI_Ignorecollisions(1);
  SF_SetObjectFlag (OF_Collidable, false);
  AI_Setthrottle(100);
  AI_Waitseconds(1);
  AI_Waitseconds(5);
  SF_SetObjectFlag (OF_Collidable, true);
  AI_Ignorecollisions(0);
  AI_Attacknothing(0);
  while(1) do begin
    AI_Waitseconds(1);
  end;
end;


function M_Epee;
begin
  SF_SetObjectFlag (OF_Alignment, ALIGN_Confed);
  AI_Waitseconds(45);
  AI_Attacknothing(1);
  SF_ActivateSelf(0);
  AI_Ignorecollisions(1);
  SF_SetObjectFlag (OF_collidable, false);
  AI_Setthrottle(100);
  AI_Waitseconds(1);
  AI_AddToWing(Faris);
  AI_Waitseconds(5);
  AI_Ignorecollisions(0);
  SF_SetObjectFlag (OF_collidable, true);
  AI_Attacknothing(0);
  while(1) do begin
    AI_Waitseconds(1);
  end;
end;

function M_scim;
begin
  SF_SetObjectFlag (OF_Alignment, ALIGN_Confed);
  SF_Activateself(0);
  SF_SubHitPoints(30);
  while(1) do begin
   AI_Waitseconds(1);
  end;
end;

function M_Skate;
begin
  SF_SetObjectFlag (OF_Alignment, ALIGN_Alien);
  while(1) do begin
    AI_Waitseconds(1);
  end;
end;

function M_Child;
begin
  SF_SetObjectFlag (OF_Alignment, ALIGN_Alien);
  while(1) do begin
    AI_Waitseconds(1);
  end;
end;

function M_Bug;
begin
  SF_SetObjectFlag (OF_Alignment, ALIGN_Alien);
  SF_ActivateSelf(0);
  while(1) do begin
    AI_Waitseconds(1);
  end;
end;

function M_DAttack;
begin
  SF_SetObjectFlag (OF_Alignment, ALIGN_Alien);
  SF_ActivateSelf(0);
  AI_Waitseconds(1);
  AI_AddToAttackList(Dauntless, 1);
  while(1) do begin
    AI_Waitseconds(1);
  end;
end;

function M_BugCount;
begin
 killcount:=killcount+1;
end;

function M_DNav;
begin
  Nav_ActivateSelf;
  SF_ActivateObject(Dauntless, 0);
  if ((not g_Fralthi_Dead) and (not g_UE_3a_Won)) then begin
    SF_ActivateObject(Fralthi_, 0);
    Nav_CreateShip(UE_SHIPID_Vaktoth_Fighter, PILOT_Vaqi, 0, @M_Kat, @D_Kat, 0, 100, -650);
    Nav_CreateShip(UE_SHIPID_Vaktoth_Fighter, PILOT_Kat4, 0, @M_Kat, @D_Kat, 0, 150, -650);
    Nav_CreateShip(UE_SHIPID_Dralthi, PILOT_Kat3, 0, @M_Kat, @D_Kat, 0, 150, -350);
  end;
  NAV_SetEjectSequence(ES_alien_pickup_MIA);
  AI_Waitseconds(1);
//Wave 1
  NAV_Createship(7, 107, 0, @M_Bug, @M_BugCount, 0, -300, 2000);
  NAV_Createship(7, 108, 0, @M_Bug, @M_BugCount, 1000, -200, 2000);
  NAV_Createship(7, 109, 0, @M_Bug, @M_BugCount, 1000, -100, 2000);
  NAV_Createship(7, 110, 0, @M_Bug, @M_BugCount, 1000, 0, 2000);
  NAV_Createship(7, 95, 0, @M_Bug, @M_BugCount, 1000, 100, 2000);
  NAV_Createship(7, 95, 0, @M_Bug, @M_BugCount, 900, 0, 2000);
  NAV_Createship(3, 114, 0, @M_Bug, @M_BugCount, -1000, 100, 2000);
  NAV_Createship(3, 115, 0, @M_Bug, @M_BugCount, -1000, 0, 2000);
  NAV_Createship(3, 116, 0, @M_Bug, @M_BugCount, -1000, -100, 2000);
                                   //8
  AI_Waitseconds(50);
// Wave 2
  Nav_Createship(3, 117, 0, @M_Bug, @M_Bugcount, -500, -300, 5000);
  Nav_Createship(3, 113, 0, @M_Bug, @M_Bugcount, -300, 300, 5000);
  Nav_Createship(3, 112, 0, @M_Bug, @M_Bugcount, -100, -500, 4000);
  Nav_Createship(3, 109, 0, @M_Bug, @M_Bugcount, 100, 100, 4000);
  //Nav_Createship(3, 107, 0, @M_Bug, @M_Bugcount, 300, 0, 4000);
  //Nav_Createship(3, 95, 0, @M_Bug, @M_Bugcount, 500, -100, 4000);
  Nav_Createship(30, 108, 0, @M_Bug, @M_Bugcount, -500, 300, 4500);
  Nav_Createship(30, 109, 0, @M_Bug, @M_Bugcount, -300, 500, 4500);
  Nav_Createship(30, 110, 0, @M_Bug, @M_Bugcount, -100, -300, 4500);
  Nav_Createship(30, 112, 0, @M_Bug, @M_Bugcount, 100, -100, 4500);
//  Nav_Createship(30, 113, 0, @M_Bug, @M_Bugcount, 300, 0, 4500);
//  Nav_Createship(30, 114, 0, @M_Bug, @M_Bugcount, 500, 100, 4500);
  AI_Waitseconds(70);
                                      //16
//Wave 3
  Nav_Createship(7, 115, 0, @M_Bug, @M_Bugcount, 500, 0, 4000);
  Nav_Createship(7, 116, 0, @M_Bug, @M_Bugcount, 700, 0, 4000);
  Nav_Createship(7, 117, 0, @M_Bug, @M_Bugcount, 700, -100, 4000);
  Nav_Createship(7, 109, 0, @M_Bug, @M_Bugcount, 500, 200, 3500);
  Nav_Createship(7, 107, 0, @M_Bug, @M_Bugcount, 700, 300, 4000);
  Nav_Createship(7, 108, 0, @M_Bug, @M_Bugcount, 700, -100, 4000);
  Nav_Createship(7, 95, 0, @M_Bug, @M_Bugcount, 500, -100, 3500);
  Nav_Createship(7, 95, 0, @M_Bug, @M_Bugcount, 700, -300, 4000);
  Nav_Createship(7, 95, 0, @M_Bug, @M_Bugcount, 700, -100, 4000);
  AI_Waitseconds(50);
                                          //24
//Wave 4
  Nav_Createship(30, 109, 0, @M_Bug, @M_Bugcount, -500, -500, 4500);
  Nav_Createship(30, 110, 0, @M_Bug, @M_Bugcount, -300, 500, 4000);
  Nav_Createship(30, 112, 0, @M_Bug, @M_Bugcount, -100, 300, 4500);
  Nav_Createship(30, 113, 0, @M_Bug, @M_Bugcount, 100, -300, 4500);
  Nav_Createship(30, 114, 0, @M_Bug, @M_Bugcount, 300, 100, 4000);
  Nav_Createship(30, 115, 0, @M_Bug, @M_Bugcount, 500, -100, 4500);
  Nav_Createship(2, 116, 0, @M_Bug, @M_Bugcount, -500, -500, 4000);
  Nav_Createship(2, 117, 0, @M_Bug, @M_Bugcount, -300, 500, 4000);
  Nav_Createship(2, 109, 0, @M_Bug, @M_Bugcount, -100, -300, 4000);
  Nav_Createship(2, 95, 0, @M_Bug, @M_Bugcount, 100, 300, 4000);
  Nav_Createship(2, 95, 0, @M_Bug, @M_Bugcount, 300, -100, 4000);
  Nav_Createship(2, 95, 0, @M_Bug, @M_Bugcount, 500, 100, 4000);
  Nav_Createship(7, 107, 0, @M_Bug, @M_Bugcount, -500, -700, 4500);
  Nav_Createship(7, 108, 0, @M_Bug, @M_Bugcount, -100, 700, 4000);
  Nav_Createship(7, 109, 0, @M_Bug, @M_Bugcount, 400, 0, 4500);

  while(1) do begin                           //41
  AI_Waitseconds(1);
    if(killcount=41)then begin
      NAV_SetEjectSequence(ES_SAR_pickup);
      SF_ObjectiveSetComplete(mobj_defend);
      SF_Setmissionsuccess;
      AI_Waitseconds(2);
      comm1check:=1;
      AI_Waitseconds(8);
      F_InitLanding;
    end;
  end;
end;

function D_Dauntless;
begin
  D_Dead := 1;
end;

function M_Fralthi;
begin
  HCL_DestroyChild(PART_ChildGunTurret, 15);
  HCL_DestroyChild(PART_ChildMissileTurret, 4);
  AI_WaitUntilActive;
  SF_SetObjectFlag(OF_alignment, ALIGN_Kilrathi);
  SF_BindToActionSphere(1);
  until (killcount > 2) do AI_WaitSeconds(1);
  AI_WaitSeconds(SYS_Random(4));
  g_Fralthi_Dead := true;
  SF_DestroySelf;
  while(1) do AI_WaitMilliseconds(1);
end;

function M_Kat;
begin
  SF_ActivateSelf(0);
  SF_SetObjectFlag(OF_alignment, ALIGN_Kilrathi);
  SF_BindToActionSphere(1);
  until(killcount > (1 + SYS_Random(12))) do
    AI_Waitseconds(1);
  SF_DestroySelf;
  while (1) do AI_WaitMilliseconds(1);
end;

function D_Kat;
begin
  AI_WaitMilliseconds(1);
end;

// **************** Takeoff/Landing routines **************
// ********************************************************
// Camera stuff

object Camera(Camera)
  x: 0;
  y: 0;
  z: 0;
  main: M_Camera;
end;

function F_Takeoff(select); forward;
function F_Landing(select); forward;

function M_Camera;
begin
  while(1) do
  begin
    if (m_Event = EVENT_Takeoff_Start) then
      F_Takeoff(SYS_Random(3));
    if (m_Event = EVENT_Activate_Landing_Cam) then
      F_Landing(SYS_Random(3));
    AI_WaitMilliSeconds(15);
  end;
end;

function F_Takeoff(select);
begin
  SF_CAM_TrackObj(Player);

  if (select = 0) then
    SF_CAM_SetFollowObj(Player, -30, 35, -40);
  if (select = 1) then
    SF_CAM_SetFollowObj(Player, -10, 35, 80);
  if (select = 2) then
    SF_CAM_SetFollowObj(Player, 0, 5, 40);

  SF_ActivateSelf(0);
  until (m_Event = EVENT_Takeoff_Complete) do
    AI_WaitSeconds(1);
  SF_CAM_TrackNothing;
  SF_DeactivateSelf(0);
end;

function F_Landing(select);
begin
  SF_CAM_HideDust;
  SF_CAM_TrackObj(NavD);
  SF_CAM_SetFollowObj(NavD, 0, 1, 0);
  SF_ActivateSelf(0);
  until (m_Event = EVENT_Dauntless_Ready) do
    AI_WaitMilliSeconds(1);
  SF_CAM_TrackObj(Dauntless);

  if (select = 0) then
    SF_CAM_SetFollowObj(Dauntless, -200, 200, -350);
  if (select = 1) then
    SF_CAM_SetFollowObj(Dauntless, -50, 200, 500);
  if (select = 2) then
    SF_CAM_SetFollowObj(Dauntless, 400, 100, 300);

  until (m_Event = EVENT_Final_Approach) do
    AI_WaitMilliSeconds(5);
  SF_CAM_TrackObj(Player);

  select := SYS_Random(3);
  if (select = 0) then
    SF_CAM_SetFollowObj(Player, -3, 2, 15);
  if (select = 1) then
    SF_CAM_SetFollowObj(Player, 3, 4, -15);
  if (select = 2) then
    SF_CAM_SetFollowObj(Player, -9, 2, 5);

  AI_WaitSeconds(30);
end;

// Player stuff

function F_InitLanding;
begin
  SF_AutopilotDisable;
  m_Event := EVENT_Land_Player;
  until (M_Event = EVENT_Activate_Landing_Cam) do AI_WaitSeconds(1);
  AI_WaitSeconds(30);
  SF_Exit;
end;

function F_PlayerTakeoff;
begin
  M_GetPos(Dauntless);
  SF_SetWorldPosition(x+15, y-25, z);
  SF_SetObjectFlag(OF_Collidable, false);
  AI_PLR_ControlAssume;
  AI_SetThrottle(0);
  AI_WaitSeconds(1);
  SF_ActivateSelf(0);
  AI_WaitSeconds(1);
  AI_SetThrottle(100);
  AI_WaitMilliSeconds(1500);
  M_Event := EVENT_Takeoff_Start;
  while (SF_GetDistance(Dauntless) < 500) do
    HCL_AI_GotoObjRelWorld_nonblock(Dauntless, 15, -20, 700);
  M_Event := EVENT_Takeoff_Complete;
  SF_SetObjectFlag(OF_Collidable, true);
  AI_PLR_ControlResume;
  SF_PlayerSwitchToCam(CamID_cockpit, Player);
end;

function F_PlayerLanding;
begin
  while (SF_GetDistance(Dauntless) > 300) do AI_WaitMilliSeconds(1);
  AI_PLR_ControlAssume;
  SF_SetObjectFlag(OF_Collidable, false);
  M_Event := EVENT_Activate_Landing_Cam;
  HCL_EmptyFuel;
  AI_SetThrottle(0);
  until (SF_GetVelocityObject(Player) < 5) do
    AI_WaitMilliSeconds(1);
  AI_SetThrottle(0);

  until (m_Event = EVENT_Dauntless_Ready) do
    AI_WaitMilliSeconds(500);

  // Teleport to position relative to Dauntless
  M_GetPos(Dauntless);
  SF_SetWorldPosition(x, y, z-350);
  AI_FaceObject(Dauntless);
  SF_SetWorldPosition(x, y-25, z-350);
  AI_SetThrottle(50);
  until (SF_GetDistance(Dauntless) < 50) do AI_WaitMilliSeconds(5);
  M_Event := EVENT_Final_Approach;
  SYS_PlaySFX(SFX_Engines_Power_Down);
  AI_WaitSeconds(3);
  AI_SetThrottle(0);
  AI_WaitSeconds(5);
  SF_Exit;
end;

// Dauntless stuff

function F_DauntlessLanding;
begin
  if (SF_GetVelocityObject(Dauntless) > 0) then
  begin
    AI_SetThrottle(0);
    AI_WaitSeconds(5);
  end;

  // Teleport to position relative to NavD, face NavD
  M_GetPos(NavD);
  SF_SetWorldPosition(x, y, z+1000);
  AI_FaceObject(NavD);
  m_Event := EVENT_Dauntless_Ready;
  AI_WaitSeconds(25);
  SF_Exit;
end;

function GF_Main;
begin
  SYS_TimerSet(5);
  while (1) do begin
    if (SYS_TimerGet = 0) then begin
      SYS_PlaySFX(UE_SFX_Scramble);
      SYS_TimerSet(20);
    end;
    GF_Exit;
  end;
end;
