//******************************************************************************
//
// Unknown Enemy
// Mission 9a - To Summon Aid
//
// Created by: Thomas Bruckner <thomas.bruckner@aon.at>
// Modified by: Alex Barnfield <alex@crius.net>
//              Jakub Majewski <qmajewski@yahoo.co.uk>
// Last modified: May 12th 2004
//
//******************************************************************************

mission ue9a;

#sector: "t.sec";

#AddToSearchPath("$uesrc$");
#AddToSearchPath("$wcue$\language\");
#include wcp, consts, uepilots;
#include UE;
#include Comms;
#SetRooms ("cic.rom", "rec.rom");

#strings objectiv;
#strings spacefli;
#strings targetid;

#SetKillboard(PILOT_Faris, PILOT_Defender, PILOT_Ocelot, PILOT_Hellcat,
              PILOT_Night, PILOT_Doc, PILOT_Shark, PILOT_Thor,
              PILOT_Killer, PILOT_Bloodhound, PILOT_Edge, PILOT_Mage,
              PILOT_Phantom, PILOT_Gold, PILOT_Blade, PILOT_Huntress,
              PILOT_Ghost, PILOT_Gryphon, PILOT_Warrior, PILOT_Vaqi);

#SetOutputPath("$wcue$\comms\");
#file "comms\srs29.pas";

#SetOutputPath("$wcue$\language\pilots\");
#file "strings\pilots\srs29.pas";

#SetOutputPath("$wcue$\mission\");
#file "block900.pas";

external
  g_Fralthi_Dead,
  g_UE_9_Won;

const
  NAV_D = 1,
  NAV_1 = 2,
  NAV_2 = 3,
  NAV_J = 4,

  EVENT_Takeoff_Start = 4,
  EVENT_Takeoff_Complete = 5,
  EVENT_Land_Player = 6,
  EVENT_Activate_Landing_Cam = 7,
  EVENT_Dauntless_Ready = 8,
  EVENT_Final_Approach = 9,
  EVENT_Zulu_Jump_Out = 10,
  EVENT_Zulu_Jump_In = 11,
  EVENT_Scene_Finished = 12;

var
  x,
  y,
  z,
  m_Nav,
  m_Nav_Route_Violation = 0,
  m_Expected_Nav = NAV_D,
  m_Enemies_Alive = 0,
  m_Counter = 0,
  m_Zulu_Returned = 0,
  m_EVENT = 0,
  briefjump = 0,
  Nav1KilledInTime = -1,
  currentcount = 0,
  landcomm=0,
  raydead = 0,
  totalturrets = 0,
  totalmissiles = 0,
  turrets = 0,
  missiles = 0,
  lostmissiles = 0,
  lostturrets = 0,
  childalive = 0,
  bugger = 0;

#name: 18;

objective mobj_escort_zulu
  hidden: false;
  type: MOBJ_Primary;
  text: objectiv["Escort Zulu to Jump Point"];
  status: MOBJ_Incomplete;
  counter: false;
end;

objective mobj_destroy_sender
  hidden: true;
  type: MOBJ_Secondary;
  text: objectiv["Destroy NAV 1 Enemies before they contact their base"];
  status: MOBJ_Incomplete;
  counter: false;
end;

objective mobj_escort_back
  hidden: true;
  type: MOBJ_Primary;
  text: objectiv["Escort Zulu back to Dauntless"];
  status: MOBJ_Incomplete;
  counter: false;
end;

objective mobj_destroy_turrets
  hidden: true;
  type: MOBJ_Bonus;
  text: objectiv["Hydra cruiser: Destroy 50% of turrets"];
  status: MOBJ_Incomplete;
  counter: true;
end;

objective mobj_destroy_missiles
  hidden: true;
  type: MOBJ_Bonus;
  text: objectiv["Hydra cruiser: Destroy 50% of missile turrets"];
  status: MOBJ_Incomplete;
  counter: true;
end;

object Jump;
object Hydra;
object Vamp;
object ZuBaka;

function M_GetPos(ShipID);
begin
  x := SF_GetXObj(ShipID);
  y := SF_GetYObj(ShipID);
  z := SF_GetZObj(ShipID);
end;

function F_InitLanding; forward;
function F_PlayerTakeoff; forward;
function F_PlayerLanding; forward;
function F_DauntlessLanding; forward;

function S_Alien;
begin
  SF_SetObjectFlag(OF_alignment, ALIGN_Alien);
  SF_ActivateSelf(0);
  AI_WaitSeconds(1);
  SF_BindToActionSphere(m_Nav);
  m_Enemies_Alive := m_Enemies_Alive + 1;
  AI_AddToAttackList(ZuBaka, 2000);

  while (1) do begin
    AI_WaitMilliSeconds(1);
    if(m_EVENT=EVENT_Zulu_Jump_Out or m_EVENT=EVENT_Zulu_Jump_In) then begin
      AI_AttackNothing(true);
      SF_SetObjectFlag (OF_Collidable, false);
      until (m_EVENT=EVENT_Scene_Finished) do AI_WaitMilliSeconds(1);
      AI_AttackNothing(false);
      SF_SetObjectFlag (OF_Collidable, true);
      AI_WaitSeconds(2);
    end;
  end;
end;

function S_AlienSquid;
begin
  SF_SetObjectFlag(OF_alignment, ALIGN_Alien);
  SF_ActivateSelf(0);
  AI_WaitSeconds(1);
  SF_BindToActionSphere(Nav_J);
  m_Enemies_Alive := m_Enemies_Alive + 1;

  while (1) do begin
    AI_WaitSeconds(1);
    if (SF_GetDistance(Hydra) > 3000) then begin
      AI_AttackNothing(1);
      AI_GotoObjRange(Hydra, 1500);
      AI_AttackNothing(0);
    end;
  end;
end;

function S_AlienDeath;
begin
  m_Enemies_Alive := m_Enemies_Alive - 1;
end;

function M_WaitUntilDeadAlien;
begin
  AI_WaitSeconds(2);
  until(m_Enemies_Alive = 0) do
    AI_WaitMilliSeconds(1);
end;

function M_SpawnAlien(shipId, count, ax, ay, az);
var
  ox, oy, oz;
begin
  while(count > 0) do begin
    ox := ax + SYS_Random(800) - 400;
    oy := ay + SYS_Random(800) - 400;
    oz := az + SYS_Random(800) - 400;

    if (m_Enemies_Alive < 50) then
      NAV_CreateShip(shipId, PILOT_Alien1, 0, @S_Alien, @S_AlienDeath, ox, oy, oz);
    AI_WaitMilliseconds(1);
    count := count - 1;
  end;
end;

function M_SpawnNearObjectAlien(shipId, count, obj);
var
  ax, ay, az,
  ox, oy, oz;
begin
  ax := SF_GetXObj(obj);
  ay := SF_GetYObj(obj);
  az := SF_GetZObj(obj);

  while(count > 0) do begin
    ox := ax + SYS_Random(200) - 100;
    oy := ay + SYS_Random(200) - 100;
    oz := az - (SYS_Random(200) + 200);

    NAV_CreateShip(shipId, PILOT_Alien1, 0, @S_Alien, @S_AlienDeath, ox, oy, oz);
    AI_WaitMilliseconds(1);
    count := count - 1;
  end;
end;

function M_SpawnNearObjectAlienSquid(shipId, count, obj);
var
  ax, ay, az,
  ox, oy, oz;
begin
  ax := SF_GetXObj(obj);
  ay := SF_GetYObj(obj);
  az := SF_GetZObj(obj);

  while(count > 0) do begin
    ox := ax + SYS_Random(200) - 100;
    oy := ay + SYS_Random(200) - 100;
    oz := az - (SYS_Random(200) + 200);

    NAV_CreateShip(shipId, PILOT_Alien1, 0, @S_AlienSquid, @S_AlienDeath, ox, oy, oz);
    AI_WaitMilliseconds(1);
    count := count - 1;
  end;
end;

function MAIN;
begin
  MS_ChangePilotSquadron(PILOT_Drago, 1);
  MS_RunGameflow(0);
  MS_RunBriefing;
  MS_ShipSelector(UE_SELECTOR_Banshee, UE_SELECTOR_Epee);
  MS_RunSpaceflight(0);
  MS_RunDebriefing;
end;

object Player(Player)
  obj: UE_SHIP_Scimitar;
  x: 0;
  y: 0;
  z: 0;
  main: M_Player;
  brief: B_Player;
  color: 0, 1.0, 1.0, 0.0;
  pilot: PILOT_Casey1;
end;

object Alpha2(Ship)
  obj: UE_SHIP_Epee;
  x: 0;
  y: 300;
  z: 0;
  main: M_Alpha2;
  brief: B_Alpha2;
  targstr: 1;
  direction: 0, 0, 1;
  color: 0, 0, 0, 1;
  pilot: PILOT_Ocelot;
end;

object Alpha3(Ship)
  obj: UE_SHIP_Banshee;
  x: 0;
  y: 300;
  z: 0;
  main: M_Alpha3;
  brief: B_Alpha3;
  targstr: 1;
  direction: 0, 0, 1;
  color: 0, 0, 0, 1;
  pilot: PILOT_Defender;
end;

// ************************* Dauntless Nav *************************

object NavD(Navpoint)
  x: 0;
  y: 0;
  z: 0;
  main: M_NavD;
  brief: B_NavD;
  name: spacefli["Dauntless Nav"];
  color: 0, 1.0, 1.0, 1.0;
  navdata: NAV_D, 35000;
end;

object Zulu(Ship)
  obj: UE_SHIP_Avenger_SAR;
  x: -15;
  y: -25;
  z: -740;
  main: M_Zulu;
  brief: B_Zulu;
  targstr: targetid["Zulu 1"];
  direction: 0, 0, 1;
  color: 0, 0, 1, 0;
  pilot: PILOT_SAR1;
end;

object Beta1(Ship)
  obj: UE_SHIP_Scimitar;
  x: -300;
  y: 50;
  z: -800;
  main: M_Beta1;
  targstr: 1;
  direction: 0, 0, 0;
  pilot: PILOT_Faris;
end;

object Beta2(Ship)
  obj: UE_SHIP_Scimitar;
  x: 300;
  y: 50;
  z: -800;
  main: M_Beta2;
  targstr: 1;
  direction: 0, 0, 0;
  pilot: PILOT_Doc;
end;

object Belt1(ABStart)
  x: 0;
  y: 0;
  z: -1000;
  absdata: 1,         // belt id
           4500,      // number of objects
           4500;      // diameter
end;

object Dauntless(Capship) as "BWS Dauntless"
  obj: UE_SHIP_Dauntless;
  x: 0;
  y: 0;
  z: -800;
  main: M_Dauntless;
  death: D_Dauntless;
  brief: B_Dauntless;
  color: 0, 0.5, 0.5, 1.0;
  pilot: PILOT_Dauntless;
end;

object ZuBaka(Capship) as "HRS Zu'Baka"
  obj: UE_SHIP_Fralthi;
  x: 800;
  y: 330;
  z: 0;
  main: M_ZuBaka;
  death: D_ZuBaka;
  direction: 10, 3, 5;
  color: 0, 0.5, 0.5, 1.0;
  pilot: PILOT_Fralthi;
end;

object Dralthi1(Ship)
  obj: UE_SHIP_Dralthi;
  x: 2100;
  y: 830;
  z: 0;
  main: M_Dralthi1;
  direction: 10, 3, 5;
  pilot: 84;
end;

object Dralthi2(Ship)
  obj: UE_SHIP_Dralthi;
  x: 2700;
  y: 830;
  z: 0;
  main: M_Dralthi2;
  direction: 10, 3, 5;
  pilot: 85;
end;

object Ray2(Cluster)
  obj: raynode2;
  x: -1000;
  y: 0;
  z: 100;
  main: M_Ray2;
  //death: S_Alien;
  EVENT_1: D_Child2;
  EVENT_0: M_Child2;
  pilot: 117;
end;

function M_NavD;
var
  setup = true;
begin
  while(1) do begin
    if (NAV_WithinSphere(Player)) then begin
      m_Enemies_Alive := 0;
      NAV_ActivateSelf;
      NAV_SetEjectSequence(ES_alien_pickup_MIA);
      m_Nav := NAV_D;
      if (m_Nav <> m_Expected_Nav) then m_Nav_Route_Violation := true;

      if (setup) then begin
        SF_ActivateObject(Dauntless, 0);
        SF_ActivateObject(Beta1, 0);
        SF_ActivateObject(Beta2, 0);
        SF_ActivateObject(ZuBaka, 0);
        SF_ActivateObject(Dralthi1, 0);
        SF_ActivateObject(Dralthi2, 0);

        m_Expected_Nav := NAV_1;
        NAV_SetPlayerNav(NAV_1);
        setup := false;
      end;

      if (m_Zulu_Returned) then begin
        SF_ObjectiveSetComplete(mobj_escort_back);
        M_SpawnAlien(UE_SHIPID_Moray, 3, -1000, 0, 0);
        SF_ActivateObject(Ray2, 0);
        if((Nav1KilledInTime = 0) or (Nav1KilledInTime = -1)) then begin
          M_SpawnAlien(UE_SHIPID_Moray, 4, -1000, 0, 0);
          M_SpawnAlien(UE_SHIPID_Manta_B, 4, -1000, 0, 0);
          M_SpawnAlien(UE_SHIPID_Barracuda, 1, -1000, 0, 0);
        end;
        if(m_Nav_Route_Violation=true) then begin
          M_SpawnAlien(UE_SHIPID_Barracuda, 2, -1000, 0, 0);
          M_SpawnAlien(UE_SHIPID_Manta_B, 4, -1000, 0, 0);
          M_SpawnAlien(UE_SHIPID_Manta, 6, -1000, 0, 0);
        end;

        M_WaitUntilDeadAlien;
        until (bugger > 1) do
          AI_WaitSeconds(1);

        NAV_SetEjectSequence(ES_SAR_PICKUP);
        if (g_Fralthi_Dead = false) then g_UE_9_Won := 1;
        SF_SetMissionSuccess;

        until (bugger = 15) do
          AI_WaitSeconds(1);

        landcomm:=1;
        AI_WaitSeconds(5);
        if (g_Fralthi_Dead = true) then SF_PrintText(900);
        F_InitLanding;
      end;

      while(NAV_WithinSphere(Player)) do begin
        AI_WaitSeconds(1);
      end;
      NAV_DeactivateSelf;
    end;
    AI_WaitSeconds(1);
  end;
end;

function M_Player;
var
  comm1 = true;
begin
  SF_SetObjectFlag(OF_Alignment, ALIGN_CONFED);
  SF_BindToActionSphere(0);
  SF_SetBaseShip(Dauntless);
  SF_ActivateSelf(0);
  F_PlayerTakeoff;

  while (1) do begin
    AI_WaitMilliseconds(250);
    if ((m_Nav = NAV_1) and (comm1)) then begin
      AI_WaitSeconds(3);
      SF_ObjectiveEnable(mobj_destroy_sender);
      AI_SendSpecialCommFrom(29, 0, PILOT_Dauntless);
      comm1 := 0;
    end;

    if(m_EVENT=EVENT_Zulu_Jump_Out or m_EVENT=EVENT_Zulu_Jump_In) then begin
      AI_PLR_ControlAssume;
      SF_SetObjectFlag (OF_Collidable, false);

      until (m_EVENT=EVENT_Scene_Finished) do AI_WaitMilliSeconds(1);

      AI_PLR_ControlResume;
      SF_PlayerSwitchToCam(CamID_cockpit, Player);
      SF_SetObjectFlag (OF_Collidable, true);
      AI_WaitSeconds(2);
      m_EVENT:= -1;
    end;

    if (m_Event = EVENT_Land_Player) then begin
      F_PlayerLanding;
    end;
  end;
end;

function M_Dauntless;
begin
  AI_WaitUntilActive;
  //SF_SaveObjectState(true);
  SF_SetChildObjectVulnerable(Dauntless, PART_ChildEngine, false);
  SF_SetChildObjectVulnerable(Dauntless, PART_ChildBridge, false);
  SF_SetObjectFlag(OF_alignment, ALIGN_Confed);
  SF_BindToActionSphere(1);
  SF_SetPilotImmortal(PILOT_Defender, 1);
  SF_SetPilotImmortal(PILOT_Faris, 1);
  SF_SetPilotImmortal(PILOT_Ocelot, 1);
  SF_SetPilotImmortal(PILOT_Doc, 1);
  SF_SetPilotImmortal(PILOT_Drago, 1);
  while(1) do begin
    AI_WaitMilliSeconds(1);
    if(landcomm=1) then begin
      AI_WaitSeconds(1);
      AI_SendSpecialComm(29, 3);
      landcomm:=0;
    end;
    if (m_Event = EVENT_Activate_Landing_Cam) then
      F_DauntlessLanding;
  end;
end;

function D_Dauntless;
begin
end;

function M_ZuBaka;
begin
  AI_WaitUntilActive;
  SF_SaveObjectState(true);
  SF_SetObjectFlag(OF_alignment, ALIGN_Kilrathi);
   SF_BindToActionSphere(1);
  while(1) do begin
    AI_WaitSeconds(1);
  end;
end;

function D_ZuBaka;
begin
  g_Fralthi_Dead := true;
end;

function M_Alpha2;
begin
  SF_SetObjectFlag(OF_alignment, ALIGN_Confed);
  SF_BindToActionSphere(0);
  SF_ActivateSelf(0);
  until (M_Event = EVENT_Takeoff_Complete) do
    AI_WaitMilliSeconds(1);
  AI_AddToWing(Player);
  until(m_Nav = NAV_J) do
    AI_WaitSeconds(1);
    AI_AddToIgnoreList(Hydra, 2000);
  SF_SetObjectFlag(OF_vulnerable, false);
  AI_WaitSeconds(100);
  SF_SetObjectFlag(OF_vulnerable, true);
  while(1) do begin
    AI_WaitMilliSeconds(200);
    if (m_Event = EVENT_Land_Player) then begin
      AI_RemoveFromWing;
      AI_IgnoreCollisions(1);
      AI_AttackNothing(1);
      AI_SetThrottle(0);
    end;
  end;
end;

function M_Alpha3;
begin
  SF_SetObjectFlag(OF_alignment, ALIGN_Confed);
  SF_BindToActionSphere(0);
  SF_ActivateSelf(0);
  until (M_Event = EVENT_Takeoff_Complete) do
    AI_WaitMilliSeconds(1);
  AI_AddToWing(Player);
  until(m_Nav = NAV_J) do
    AI_WaitSeconds(1);
  AI_AddToIgnoreList(Hydra, 2000);
  AI_SendComm(COMM_PILOT_REPORT_BIG_EVENT_OR_SURPRISE);
  SF_SetObjectFlag(OF_vulnerable, false);
  AI_WaitSeconds(100);
  SF_SetObjectFlag(OF_vulnerable, true);
  while(1) do begin
    AI_WaitMilliSeconds(200);
    if (m_Event = EVENT_Land_Player) then begin
      AI_RemoveFromWing;
      AI_IgnoreCollisions(1);
      AI_AttackNothing(1);
      AI_SetThrottle(0);
    end;
  end;
end;

function M_Beta1;
begin
  AI_WaitUntilActive;
  SF_SetObjectFlag(OF_alignment, ALIGN_Confed);
  SF_BindToActionSphere(1);

  while(1) do begin
    AI_WaitSeconds(1);
    while(m_Enemies_Alive = 0) do begin
      AI_WaitSeconds(1);
      AI_GotoObjRelFrame(Dauntless, -400, 350, -800);
      AI_GotoObjRelFrame(Dauntless, 400, 350, 800);
    end;
    //AI_AttackEnemies;
  end;
end;

function M_Beta2;
begin
  AI_WaitUntilActive;
  SF_SetObjectFlag(OF_alignment, ALIGN_Confed);
  SF_BindToActionSphere(1);

  while(1) do begin
    AI_WaitSeconds(1);
    while(m_Enemies_Alive = 0) do begin
      AI_WaitSeconds(1);
      AI_GotoObjRelFrame(Dauntless, 400, 350, -600);
      AI_GotoObjRelFrame(Dauntless, -400, 350, 600);
    end;
    //AI_AttackEnemies;
  end;
end;

function M_Zulu;
begin
  SF_SetObjectFlag(OF_alignment, ALIGN_Confed);
  SF_SetObjectFlag(OF_vulnerable, false);
  SF_BindToActionSphere(0);
  SF_ActivateSelf(0);
  AI_MuteComms;
  AI_AttackNothing(1);

  until (M_Event = EVENT_Takeoff_Complete) do
    HCL_AI_GotoObjRelWorld_nonblock(Dauntless, -15, -20, 700);
//    AI_WaitMilliSeconds(1);
  AI_AddToWing(Player);

  until(m_Nav = NAV_J) do
    AI_WaitSeconds(1);
  AI_RemoveFromWing;
  AI_AttackNothing(1);
  AI_WaitSeconds(2);
  // "All right sir, we're going for the jump point!"
  AI_SendSpecialComm(29, 1);
  AI_WaitSeconds(1);
  AI_GotoObjRange(Jump, 200);
  m_EVENT:=EVENT_Zulu_Jump_Out;
  AI_WaitSeconds(3);
  SF_ObjectiveSetComplete(mobj_escort_zulu);
  SF_DeactivateSelf(1);

  AI_SetThrottle(0);
  SF_SetWorldPosition(9900, 25050, 130000);

  AI_WaitUntilActive;
  m_Zulu_Returned := true;
  SF_ObjectiveEnable(mobj_escort_back);
  AI_WaitSeconds(1);
  AI_SendSpecialComm(29, 2);
  AI_AddToWing(Player);
  while (1) do
    AI_WaitSeconds(1);
end;

function M_Dralthi1;
begin
  AI_WaitUntilActive;
  SF_SetObjectFlag(OF_alignment, ALIGN_Kilrathi);
  SF_BindToActionSphere(1);
  while(1) do begin
    AI_WaitSeconds(1);
    while(m_Enemies_Alive = 0) do begin
      AI_WaitSeconds(1);
      AI_GotoObjRelFrame(ZuBaka, -300, 200, 0);
      AI_GotoObjRelFrame(ZuBaka, 300, 200, 0);
    end;
    //AI_AttackEnemies;
  end;
end;

function M_Dralthi2;
begin
  AI_WaitUntilActive;
  SF_SetObjectFlag(OF_alignment, ALIGN_Kilrathi);
  SF_BindToActionSphere(1);
  while(1) do begin
    AI_WaitSeconds(1);
    while(m_Enemies_Alive = 0) do begin
      AI_WaitSeconds(1);
      AI_GotoObjRelFrame(ZuBaka, 300, -350, 0);
      AI_GotoObjRelFrame(ZuBaka, -300, -350, 0);
    end;
    //AI_AttackEnemies;
  end;
end;

function M_Ray2;
begin
  bugger := bugger +1;
  SF_SetObjectFlag(OF_alignment, ALIGN_Alien);
  AI_WaitUntilActive;
  SF_BindToActionSphere(m_Nav);
  AI_AttackEnemies;
  while (1) do
    AI_WaitSeconds(1);
end;

function M_Child2;
begin
  bugger := bugger +1;
  AI_MuteComms;
  SF_SetObjectFlag (OF_Alignment, ALIGN_Alien);
  while(1) do begin
    AI_Waitseconds(1);
  end;
end;

function D_Child2;
begin
  bugger := bugger +1;
end;

// *****************************  Nav1 *****************************

object Nav1(Navpoint)
  x: 10000;
  y: 0;
  z: 60000;
  main: M_Nav1;
  brief: B_Nav1;
  name: spacefli["Nav 1"];
  color: 0, 1.0, 1.0, 1.0;
  navdata: NAV_1, 15000;
end;

object Belt2(ABStart)
  x: 10000;
  y: 0;
  z: 60000;
  absdata: 2,         // belt id
           750,      // number of objects
           1600;      // diameter
end;

object Ray(Cluster)
  obj: raynode2;
  x: 10000;
  y: 0;
  z: 62100;
  main: M_Ray;
  //death: S_Alien;
  EVENT_1: D_Child;
  EVENT_0: M_Child;
  pilot: 117;
end;

function M_Ray;
begin
  raydead := false;
  SF_SetObjectFlag(OF_alignment, ALIGN_Alien);
  AI_WaitUntilActive;
  SF_BindToActionSphere(m_Nav);
  AI_AttackEnemies;
  while (1) do
    AI_WaitSeconds(1);
end;

function M_Child;
begin
  childalive := childalive +1;
  AI_WaitMilliSeconds(SYS_Random(50));
  if (raydead = false) then
    raydead := true;
  AI_MuteComms;
  SF_SetObjectFlag (OF_Alignment, ALIGN_Alien);
  while(1) do begin
    AI_Waitseconds(1);
  end;
end;

function D_Child;
begin
  childalive := childalive -1;
end;

function D_Bug;
begin
end;


function M_Nav1;
var
  setup = true;
begin
  while(1) do begin
    if (NAV_WithinSphere(Player)) then begin
      m_Enemies_Alive := 0;
      NAV_ActivateSelf;
      NAV_SetEjectSequence(ES_ALIEN_PICKUP_MIA);
      m_Nav := NAV_1;
      if (m_Nav <> m_Expected_Nav) then m_Nav_Route_Violation := true;

      if (setup) then begin
        SF_ActivateObject(Ray, 0);
        M_SpawnAlien(UE_SHIPID_Moray, 2, 10000, 0, 62050);

        m_Counter := SYS_Clock;
        M_WaitUntilDeadAlien;
        until (raydead = true) do AI_WaitMilliSeconds(1);

        m_Counter := SYS_Clock - m_Counter;
        AI_WaitSeconds(1);

        if (m_Counter < 35) then begin
          SF_ObjectiveSetComplete(mobj_destroy_sender);
          Nav1KilledInTime:=1;
        end
        else begin
          SF_ObjectiveSetFailure(mobj_destroy_sender);
          Nav1KilledInTime:=0;
        end;

        m_Expected_Nav := NAV_2;
        NAV_SetPlayerNav(NAV_2);

        setup := false;
      end;

      if (m_Zulu_Returned) then begin
        NAV_SetEjectSequence(ES_SAR_PICKUP);
        M_WaitUntilDeadAlien;
        m_Expected_Nav := NAV_D;
        NAV_SetPlayerNav(NAV_D);
      end;

      while(NAV_WithinSphere(Player)) do begin
        AI_WaitSeconds(1);
      end;
      NAV_DeactivateSelf;
    end;
    AI_WaitSeconds(1);
  end;
end;

// *****************************  Nav2 *****************************

object Nav2(Navpoint)
  x: 5000;
  y: 0;
  z: 100000;
  main: M_Nav2;
  brief: B_Nav2;
  name: spacefli["Nav 2"];
  color: 0, 1.0, 1.0, 1.0;
  navdata: NAV_2, 15000;
end;

function M_Nav2;
var
  setup = true;
begin
  while(1) do begin
    if (NAV_WithinSphere(Player)) then begin
      m_Enemies_Alive := 0;
      NAV_ActivateSelf;
      NAV_SetEjectSequence(ES_ALIEN_PICKUP_MIA);
      m_Nav := NAV_2;
      if (m_Nav <> m_Expected_Nav) then m_Nav_Route_Violation := true;

      if (setup) then begin
        M_SpawnAlien(UE_SHIPID_Manta, 2, 5000, 0, 101500);
        M_SpawnAlien(UE_SHIPID_Moray, 4, 5000, 0, 102000);
        //M_SpawnAlien(UE_SHIPID_Stingray 3, 5000, 0, 102500);
        M_WaitUntilDeadAlien;
        m_Expected_Nav := NAV_J;
        NAV_SetPlayerNav(NAV_J);
        setup := false;
      end;
      if (m_Zulu_Returned) then begin
        NAV_SetEjectSequence(ES_SAR_PICKUP);
        M_WaitUntilDeadAlien;
        m_Expected_Nav := NAV_1;
        NAV_SetPlayerNav(NAV_1);
      end;

      while(NAV_WithinSphere(Player)) do begin
        AI_WaitSeconds(1);
      end;
      NAV_DeactivateSelf;
    end;
    AI_WaitSeconds(1);
  end;
end;

// **************************  Jumppoint Nav **************************

object NavJ(Navpoint)
  x: 10000;
  y: 25000;
  z: 129000;
  main: M_NavJ;
  brief: B_NavJ;
  name: spacefli["Jump Point Nav"];
  color: 0, 1.0, 1.0, 1.0;
  navdata: NAV_J, 15000;
end;

object Hydra(Capship)
  obj: "marlin";
  x: 10000;
  y: 25300;
  z: 134500;
  main: M_Hydra;
  direction: 110, 15, 0;
  pilot: PILOT_Cruiser;
end;

object Jump(Jumppoint)
  x: 10000;
  y: 25000;
  z: 131000;
  actionsphere: NAV_J;
end;

object Vamp(Ship)
  obj: "vampire";
  x: 9940;
  y: 25055;
  z: 130005;
  main: M_Vamp;
  targstr: 1;
  direction: 0, 0, 0;
  pilot: PILOT_Drago;
end;

function M_NavJ;
var
  setup = true,
  time = -20;
begin
  while(1) do begin
    if (NAV_WithinSphere(Player)) then begin
      NAV_ActivateSelf;
      NAV_SetEjectSequence(ES_ALIEN_PICKUP_MIA);
      m_Nav := NAV_J;
      if (m_Nav <> m_Expected_Nav) then m_Nav_Route_Violation := true;

      if (setup) then begin
        SF_AutopilotDisable;

        // Wave 1 - Orca, 3 Manta
        SF_ActivateObject(Hydra, 0);
        //AI_WaitSeconds(5);
        M_SpawnNearObjectAlien(UE_SHIPID_Manta, 2, Hydra);
        M_SpawnNearObjectAlien(UE_SHIPID_Moray, 4, Hydra);

        // Wave 2 (60 seconds after player's arrival) - 3 Mantas
        AI_WaitSeconds(60);
        M_SpawnNearObjectAlien(UE_SHIPID_Manta, 2, Hydra);
        AI_WaitSeconds(60);
        M_SpawnNearObjectAlien(UE_SHIPID_Moray, 5, Hydra);

        // Wave 3 (3 minutes after player's arrival) - 2 Devil Rays
        AI_WaitSeconds(60);
        M_SpawnNearObjectAlien(UE_SHIPID_Warlord, 2, Hydra);
        //M_SpawnNearObjectAlien(UE_SHIPID_Stingray, 2, Hydra);
        //M_SpawnNearObjectAlien(UE_SHIPID_Moray, 3, Hydra);

        // Wave 4 (4 minutes after player's arrival) - 6 Morays
        AI_WaitSeconds(60);
        M_SpawnNearObjectAlien(UE_SHIPID_Moray, 6, Hydra);
        //M_SpawnNearObjectAlien(UE_SHIPID_Manta, 2, Hydra);

        // 30 seconds more and Zulu will be back
        AI_WaitSeconds(30);
        m_EVENT:=EVENT_Zulu_Jump_In;
        AI_WaitMilliSeconds(100);
        SF_ActivateObject(Zulu, 1);
        SF_ActivateObject(Vamp, 1);
        //M_WaitUntilDeadAlien;
        SF_AutopilotResumeNormal;
        m_Expected_Nav := NAV_2;
        NAV_SetPlayerNav(NAV_2);
        setup := false;
      end;

      while(NAV_WithinSphere(Player)) do begin
        time := time + 1;
        if (time = 90) then begin
          if (m_Enemies_Alive < 35) then M_SpawnNearObjectAlienSquid(UE_SHIPID_Squid, 5, Hydra);
          time := 0;
        end;
        AI_WaitSeconds(1);
      end;
      NAV_DeactivateSelf;
    end;
    AI_WaitSeconds(1);
  end;
end;

function M_Hydra;
begin
  SF_SetObjectFlag(OF_alignment, ALIGN_Alien);
  SF_SaveObjectState(true);
  AI_WaitUntilActive;
  SF_ObjectiveEnable(mobj_destroy_turrets);
  SF_ObjectiveEnable(mobj_destroy_missiles);
  SF_BindToActionSphere(m_Nav);
  AI_FaceObject(Jump);
  AI_SetThrottle(15);
  totalturrets := SF_GetNumComponentPartsObj(Hydra, PART_ChildGunTurret);
  totalmissiles := SF_GetNumComponentPartsObj(Hydra, PART_ChildMissileTurret);
  SF_ObjectiveSetTotal(mobj_destroy_turrets, totalturrets);
  SF_ObjectiveSetTotal(mobj_destroy_missiles, totalmissiles);
  SF_ObjectiveSetTotalNeededForSuccess(mobj_destroy_turrets, (totalturrets/2));
  SF_ObjectiveSetTotalNeededForSuccess(mobj_destroy_missiles, (totalmissiles/2));
  while(1) do begin
    AI_WaitMilliSeconds(1);
    if (SF_GetDistance(Jump) < 1000) then
      AI_SetThrottle(0);

    turrets := SF_GetNumComponentPartsObj(Hydra, PART_ChildGunTurret);
    lostturrets := totalturrets - turrets;
    missiles := SF_GetNumComponentPartsObj(Hydra, PART_ChildMissileTurret);
    lostmissiles := totalmissiles - missiles;

    SF_ObjectiveSetCount(mobj_destroy_turrets, lostturrets);
    SF_ObjectiveSetCount(mobj_destroy_missiles, lostmissiles);
  end;
end;

function M_Vamp;
begin
  SF_SetObjectFlag(OF_alignment, ALIGN_Confed);
  SF_SetObjectFlag(OF_vulnerable, false);
  AI_MuteComms;
  AI_WaitUntilActive;
  SF_BindToActionSphere(0);
  AI_AddToWing(Player);
  AI_WaitSeconds(2);
  AI_ResumeComms;
  AI_SendComm(10);
  while(1) do
    AI_WaitMilliSeconds(1);
    if(landcomm=1) then AI_MuteComms;
end;

// ***************** View Jump Out/ Jump In ***************
// ********************************************************

object Camera2(Camera)
  x: 0;
  y: 0;
  z: 0;
  main: M_Camera2;
end;


function M_Camera2;
begin
  while(1) do
  begin
    until (m_Event = EVENT_Zulu_Jump_Out) do
      AI_WaitMilliSeconds(1);
    M_GetPos(Zulu);
    SF_CAM_SetPos(x-120, y, z);
    SF_CAM_TrackObj(Zulu);

    SF_CAM_SetActive(1);
    AI_WaitMilliSeconds(2000);
    SF_CAM_TrackNothing;
    AI_WaitSeconds(2);
    SF_CAM_SetActive(0);
    m_EVENT:=EVENT_Scene_Finished;
    AI_WaitMilliSeconds(5);
    SF_DeactivateSelf(0);
    until (m_Event = EVENT_Zulu_Jump_In) do
      AI_WaitMilliSeconds(200);
    M_GetPos(Zulu);
    SF_CAM_SetPos(x-20, y, z+130);
    SF_CAM_TrackObj(Vamp);
    //SF_CAM_TrackNothing;
    SF_CAM_SetActive(1);
//    AI_WaitSeconds(1);
    SF_CAM_TrackPivotObjects(Vamp, Zulu, 2);
    AI_WaitSeconds(1);
    m_EVENT:=EVENT_Scene_Finished;
    AI_WaitMilliSeconds(5);
    SF_DeactivateSelf(0);
  end;
end;


// ******************** Begin Briefing ********************

function B_Player;
begin
  BRIEF_CAM_SetActive(1);
  BRIEF_CAM_SetPos(0, 400, 0);
  BRIEF_CAM_TrackObj(Player);
  BRIEF_SetAppearance(UE_APPEARANCE_Epee);
  BRIEF_FaceObject(Nav1);
  BRIEF_Activate;

  // "Your Alpha wing will escort the Avenger to the Venice jump point to ensure
  // its safe jump out-system."
  BRIEF_VoiceOver(29, 0, 10);
  BRIEF_MoveObjSeconds(Nav1, 5);
  SYS_PlaySFX(SFX_BRIEF_Activate);

//  BRIEF_WaitSeconds(1);
  BRIEF_MoveObjSeconds(Nav2, 5);
  SYS_PlaySFX(SFX_BRIEF_Activate);
  BRIEF_MoveObjSeconds(NavJ, 5);
  SYS_PlaySFX(SFX_BRIEF_Activate);
  BRIEF_WaitSeconds(1);
  briefjump:=1;

  // "If there is already a Nephilem presence inside the Venice System, the
  // Avenger may need to abort its mission. Therefore, you must wait at the jump
  // point for 10 minutes following its jump and if it returns, escort it back to the Dauntless."
  BRIEF_VoiceOver(29, 1, 20);
    BRIEF_WaitSeconds(5);
  briefjump:=2;
  BRIEF_WaitSeconds(2);
  BRIEF_MoveObjSeconds(Nav2, 5);
  SYS_PlaySFX(SFX_BRIEF_Activate);
  //BRIEF_WaitSeconds(2);
//  BRIEF_WaitSeconds(1);
  BRIEF_MoveObjSeconds(Nav1, 5);
  SYS_PlaySFX(SFX_BRIEF_Activate);
  // Your nav route has been plotted to ensure your wing cannot be traced back to
  // the Dauntless. Failure to follow this route to the letter may put the Dauntless in grave danger.
  BRIEF_VoiceOver(29, 2, 15);

//  BRIEF_WaitSeconds(1);
  BRIEF_MoveObjSeconds(NavD, 5);

  BRIEF_Exit;

  while (1) do
    BRIEF_WaitSeconds(1);
end;

function B_Alpha2;
begin
  BRIEF_SetAppearance(UE_APPEARANCE_Epee);
  BRIEF_AttachToObj(Player, 25, 0, -5);
  BRIEF_Activate;
  BRIEF_FaceObject(Nav1);
  while(1) do
    BRIEF_WaitSeconds(10);
end;

function B_Alpha3;
begin
  BRIEF_SetAppearance(UE_APPEARANCE_Epee);
  BRIEF_AttachToObj(Player, -25, 0, -5);
  BRIEF_FaceObject(Nav1);
  BRIEF_Activate;
  while(1) do
    BRIEF_WaitSeconds(10);
end;

function B_Zulu;
begin
  BRIEF_SetAppearance(18);
  BRIEF_AttachToObj(Player, 0, 0, -30);
  BRIEF_FaceObject(Nav1);
  BRIEF_Activate;
  until(briefjump=1) do BRIEF_WaitSeconds(1);
  SYS_PlaySFX(SFX_Jump);
  BRIEF_Deactivate;
  until(briefjump=2) do BRIEF_WaitSeconds(1);
  SYS_PlaySFX(SFX_Jump);
  BRIEF_Activate;
  while(1) do
    BRIEF_WaitSeconds(10);
end;

function B_Dauntless;
begin
  BRIEF_SetAppearance(UE_APPEARANCE_Dauntless);
  BRIEF_FaceObject(Nav1);
  BRIEF_Activate;

  while(1) do
    BRIEF_WaitSeconds(10);
end;

function B_NavD;
begin
  BRIEF_Activate;
  BRIEF_DisplayName(1);
  BRIEF_SetSize(160);
  BRIEF_SetAppearance(1);

  while (1) do
    BRIEF_WaitSeconds(1);
end;

function B_Nav1;
begin
  BRIEF_Activate;
  BRIEF_DisplayName(1);
  BRIEF_SetSize(160);
  BRIEF_SetAppearance(1);

  while (1) do
    BRIEF_WaitSeconds(1);
end;

function B_Nav2;
begin
  BRIEF_Activate;
  BRIEF_DisplayName(1);
  BRIEF_SetSize(160);
  BRIEF_SetAppearance(1);

  while (1) do
    BRIEF_WaitSeconds(1);
end;

function B_NavJ;
begin
  BRIEF_Activate;
  BRIEF_DisplayName(1);
  BRIEF_SetSize(125);
  BRIEF_SetAppearance(1);

  while (1) do
    BRIEF_WaitSeconds(1);
end;



// **************** Takeoff/Landing routines **************
// ********************************************************
// Camera stuff

object Camera(Camera)
  x: 0;
  y: 0;
  z: 0;
  main: M_Camera;
end;

function F_Takeoff(select); forward;
function F_Landing(select); forward;

function M_Camera;
begin
  while(1) do
  begin
    if (m_Event = EVENT_Takeoff_Start) then
      F_Takeoff(SYS_Random(3));
    if (m_Event = EVENT_Activate_Landing_Cam) then
      F_Landing(SYS_Random(3));
    AI_WaitMilliSeconds(15);
  end;
end;

function F_Takeoff(select);
begin
  SF_CAM_TrackObj(Player);

  if (select = 0) then
    SF_CAM_SetFollowObj(Player, -30, 35, -40);
  if (select = 1) then
    SF_CAM_SetFollowObj(Player, -10, 35, 80);
  if (select = 2) then
    SF_CAM_SetFollowObj(Player, 0, 5, 40);

  SF_ActivateSelf(0);
  until (m_Event = EVENT_Takeoff_Complete) do
    AI_WaitSeconds(1);
  SF_CAM_TrackNothing;
  SF_DeactivateSelf(0);
end;

function F_Landing(select);
begin
  SF_CAM_HideDust;
  SF_CAM_TrackObj(NavD);
  SF_CAM_SetFollowObj(NavD, 0, 1, 0);
  SF_ActivateSelf(0);
  until (m_Event = EVENT_Dauntless_Ready) do
    AI_WaitMilliSeconds(1);
  SF_CAM_TrackObj(Dauntless);

  if (select = 0) then
    SF_CAM_SetFollowObj(Dauntless, -200, 200, -350);
  if (select = 1) then
    SF_CAM_SetFollowObj(Dauntless, -50, 200, 500);
  if (select = 2) then
    SF_CAM_SetFollowObj(Dauntless, 400, 100, 300);

  until (m_Event = EVENT_Final_Approach) do
    AI_WaitMilliSeconds(5);
  SF_CAM_TrackObj(Player);

  select := SYS_Random(3);
  if (select = 0) then
    SF_CAM_SetFollowObj(Player, -3, 2, 15);
  if (select = 1) then
    SF_CAM_SetFollowObj(Player, 3, 4, -15);
  if (select = 2) then
    SF_CAM_SetFollowObj(Player, -9, 2, 5);

  AI_WaitSeconds(30);
end;

// Player stuff

function F_InitLanding;
begin
  SF_AutopilotDisable;
  m_Event := EVENT_Land_Player;
  until (M_Event = EVENT_Activate_Landing_Cam) do AI_WaitSeconds(1);
  AI_WaitSeconds(30);
  SF_Exit;
end;

function F_PlayerTakeoff;
begin
  M_GetPos(Dauntless);
  SF_SetWorldPosition(x+15, y-25, z);
  SF_SetObjectFlag(OF_Collidable, false);
  AI_PLR_ControlAssume;
  AI_SetThrottle(0);
  AI_WaitSeconds(1);
  SF_ActivateSelf(0);
  AI_WaitSeconds(1);
  AI_SetThrottle(100);
  AI_WaitMilliSeconds(1500);
  M_Event := EVENT_Takeoff_Start;
  while (SF_GetDistance(Dauntless) < 500) do
    HCL_AI_GotoObjRelWorld_nonblock(Dauntless, 15, -20, 700);
  M_Event := EVENT_Takeoff_Complete;
  SF_SetObjectFlag(OF_Collidable, true);
  AI_PLR_ControlResume;
  SF_PlayerSwitchToCam(CamID_cockpit, Player);
end;

function F_PlayerLanding;
begin
  while (SF_GetDistance(Dauntless) > 300) do AI_WaitMilliSeconds(1);
  AI_PLR_ControlAssume;
  SF_SetObjectFlag(OF_Collidable, false);
  M_Event := EVENT_Activate_Landing_Cam;
  HCL_EmptyFuel;
  AI_SetThrottle(0);
  until (SF_GetVelocityObject(Player) < 5) do
    AI_WaitMilliSeconds(1);
  AI_SetThrottle(0);

  until (m_Event = EVENT_Dauntless_Ready) do
    AI_WaitMilliSeconds(500);

  // Teleport to position relative to Dauntless
  M_GetPos(Dauntless);
  SF_SetWorldPosition(x, y, z-350);
  AI_FaceObject(Dauntless);
  SF_SetWorldPosition(x, y-25, z-350);
  AI_SetThrottle(50);
  until (SF_GetDistance(Dauntless) < 50) do AI_WaitMilliSeconds(5);
  M_Event := EVENT_Final_Approach;
  SYS_PlaySFX(SFX_Engines_Power_Down);
  AI_WaitSeconds(3);
  AI_SetThrottle(0);
  AI_WaitSeconds(5);
  SF_Exit;
end;

// Dauntless stuff

function F_DauntlessLanding;
begin
  if (SF_GetVelocityObject(Dauntless) > 0) then
  begin
    AI_SetThrottle(0);
    AI_WaitSeconds(5);
  end;

  // Teleport to position relative to NavD, face NavD
  M_GetPos(NavD);
  SF_SetWorldPosition(x, y, z+1000);
  AI_FaceObject(NavD);
  m_Event := EVENT_Dauntless_Ready;
  AI_WaitSeconds(25);
  SF_Exit;
end;


